All of lore.kernel.org
 help / color / mirror / Atom feed
* Re: Hardwired drivers are going away?
From: Horst von Brand @ 2002-01-15 10:45 UTC (permalink / raw)
  To: David Lang; +Cc: linux-kernel
In-Reply-To: <Pine.LNX.4.40.0201141055410.22904-100000@dlang.diginsite.com>

> On Mon, 14 Jan 2002, Alan Cox wrote:

> > > 1. security, if you don't need any modules you can disable modules
> > > entirly and then it's impossible to add a module without patching
> > > the kernel first (the module load system calls aren't there)

> > Urban legend.

> If this is the case then why do I get systemcall undefined error messages
> when I make a mistake and attempt to load a module on a kernel without
> modules enabled?

AFAIU the security improvement of no-modules are way overrated.

[...]

> > > 3. simplicity in building kernels for other machines. with a monolithic
> > > kernel you have one file to move (and a bootloader to run) with modules
> > > you have to move quite a few more files.

> > tar or nfs mount; make modules_install.

> not on my firewalls thank you.

You keep compilers and stuff on your firewalls then?!

I get them over via ssh or by floppy/CD. Same idea.
-- 
Horst von Brand			     http://counter.li.org # 22616

^ permalink raw reply

* Re: Aunt Tillie builds a kernel (was Re: ISA hardware discovery --the elegant solution)
From: Zwane Mwaikambo @ 2002-01-15 10:40 UTC (permalink / raw)
  To: Linux Kernel

This all sounds like distro work to me. Distributions could put the
userland apps in place to allow "automagic" tuning, recompilation etc
based on questions asked of the user. This Supe-Me-Up app could even
download the latest _Distro_Tested_ kernel and use that as the basis of
the new tuned one. Really i don't see what any of this has to do with
Linux Kernel. Eric i'm not putting down your excellent work, but i really
don't see where this is going, Normal users should _never_ have to use
kernel.org trees.

Regards,
	Zwane Mwaikambo



^ permalink raw reply

* Re: Memory problem with bttv driver
From: Gerd Knorr @ 2002-01-15 10:17 UTC (permalink / raw)
  To: linux-kernel
In-Reply-To: <20020115004205.A12407@werewolf.able.es>

> >Making it bigger reduces that amount of ram directly mapped by the kernel 
> >which hits performance (nastily for 2.4 not so bad for 2.5)
>  
>  (Sorry for joning so late to the thread...)
>  It is wokring fine for me, under 2.4.18-pre3 + NVidia. The difference is
>  that I am using version 0.7.87 (see http://giga.cps.unizar.es/~magallon/linux/2.4.18-pre3/)
>  I have just checked the bttv page (http://bytesex.org/bttv/) and there is
>  a newer version (0.7.88). What comes in .17 is 0.7.83. I have not
>  noticed anything relevant in changelog, but you can try...

MM wise it shouldn't make a difference whenever you are using 0.7.83 or
0.7.88 (I've mailed 0.7.88 patches to macelo for 2.4.18 btw).  The 0.8.x
versions have a complete different way to do the memory management.

  Gerd

-- 
#define	ENOCLUE 125 /* userland programmer induced race condition */

^ permalink raw reply

* Re: compile error 2.4.17
From: Silviu Marin-Caea @ 2002-01-15 10:24 UTC (permalink / raw)
  To: linux-kernel
In-Reply-To: <20020115121123.78594eb7.silviu@delrom.ro>

On Tue, 15 Jan 2002 12:11:23 +0200
Silviu Marin-Caea <silviu@delrom.ro> wrote:

> I'm trying to compile a minimalistic custom kernel for a bootable
> diskette.

If I enable the kernel module loader, compilation works.  I don't need
it, I'm building that kernel with everything compiled in, no modules.

grep "=m" .config shows nothing

-- 
Silviu Marin-Caea - Network & Systems Administrator - Delta Romania
Phone +4093-267961


^ permalink raw reply

* 8240 booting:bootp time out and hd lost interrupt
From: 邹涛 @ 2002-01-15 10:22 UTC (permalink / raw)
  To: linuxppc-embedded@lists.linuxppc.org


Hello:
  I'm a newer to PowerPC. when i port linux to PowerPC 8240,i met some problem.anyone give me advices will be appreciate.
  i use board sandpoint 3, the cpu board is mpc8240.
  I mark the line i wish you pay attention to.i have two questions: one is why the hdc lost the interrupt. the other is why the bootp time out. i test the host dhcp configuration with win98 as client.
  The dip switch on cpu board is set to : sw2 01111,sw3 11011 (1 means ON)
  BTW,who could tell me every bit of the two dip switch mean? I couldn't find document about it.
  The dip switch on main board is set to: sw1 11111010 ,sw2 11111111.
  The type of main board is "ppceval-sp3 rev x3". the CPU board is
"m98ppmc8240 rev x2" .linux kernel is Mvista Hard Hat Linux 2.0 for
 ppc 82xx. My hard disk type is "Quantum fireball 3.5series 30.0GB".
  the following is bootup message:

       DINK32_KAHLUA >>dl -k
     #>ascii-xfr -svn -l 10 vmlinuz-motolola-sandpoint.srec>/dev/ttyS0
     DINK32_KAHLUA >>go 900000
loaded at:     00900000 009091B8
relocated to:  00800000 008091B8
zimage at:     00906000 00998F41
avail ram:     00400000 00800000

Linux/PPC load:
Uncompressing Linux...done.
Now booting the kernel
Total memory = 32MB; using 0kB for hash table (at 00000000)
Linux version 2.4.2_hhl20 (root@tony) (gcc version 2.95.3 20010315 (release/Mon1Motorola SPS Sandpoint Test Platform
Sandpoint port (C) 2000, 2001 MontaVista Software, Inc. (source@mvista.com)
On node 0 totalpages: 8192
zone(0): 8192 pages.
zone(1): 0 pages.
zone(2): 0 pages.
Kernel command line:
OpenPIC Version 1.2 (1 CPUs and 24 IRQ sources) at f7fd0000
OpenPIC timer frequency is 100.000000 MHz
time_init: decrementer frequency = 24.752286 MHz
Calibrating delay loop... 131.89 BogoMIPS
Memory: 30596k available (1048k kernel code, 440k data, 88k init, 0k highmem)
Dentry-cache hash table entries: 4096 (order: 3, 32768 bytes)
Buffer-cache hash table entries: 1024 (order: 0, 4096 bytes)
Page-cache hash table entries: 8192 (order: 3, 32768 bytes)
Inode-cache hash table entries: 2048 (order: 2, 16384 bytes)
POSIX conformance testing by UNIFIX
PCI: Probing PCI hardware
Linux NET4.0 for Linux 2.4
Based upon Swansea University Computer Society NET3.039
Starting kswapd v1.8
pty: 256 Unix98 ptys configured
block: queued sectors max/low 20256kB/6752kB, 64 slots per queue
RAMDISK driver initialized: 16 RAM disks of 4096K size 1024 blocksize
Uniform Multi-Platform E-IDE driver Revision: 6.31
ide: Assuming 33MHz system bus speed for PIO modes; override with idebus=xx
W82C105: IDE controller on PCI bus 00 dev 59
W82C105: chipset revision 5
W82C105: 100% native mode on irq 17
    ide0: BM-DMA at 0xbfffd0-0xbfffd7, BIOS settings: hda:pio, hdb:pio
SL82C105 command word: 5
IDE timing: 00000909, resetting to PIO0 timing
  ide1: BM-DMA at 0xbfffd8-0xbfffdf, BIOS settings: hdc:pio, hdd:pio
SL82C105 command word: 5
IDE timing: 000003e4, resetting to PIO0 timing
hdc: QUANTUM FIREBALLP AS30.0, ATA DISK drive
ide1 at 0xbfffe8-0xbfffef,0xbfffe6 on irq 15
hdc: 58633344 sectors (30020 MB) w/1902KiB Cache, CHS=58168/16/63
/*******************************************************************************
Partition check:
 hdc:hdc: lost interrupt
hdc: lost interrupt
hdc: lost interrupt
hdc: lost interrupt
hdc: lost interrupt
 [PTBL] [3649/255/63] hdc1 <hdc: lost interrupt
hdc: lost interrupt
 hdc5hdc: lost interrupt
hdc: lost interrupt
 hdc6 >
*******************************************************************************/
loop: loaded (max 8 devices)
Serial driver version 5.02 (2000-08-09) with MANY_PORTS SHARE_IRQ SERIAL_PCI endttyS00 at 0x03f8 (irq = 4) is a 16550A
ttyS01 at 0x02f8 (irq = 3) is a 16550A
NET4: Linux TCP/IP 1.0 for NET4.0
IP Protocols: ICMP, UDP, TCP
IP: routing cache hash table of 512 buckets, 4Kbytes
TCP: Hash tables configured (established 2048 bind 2048)
/*******************************************************************************
Sending BOOTP requests.......<6>NETDEV WATCHDOG: eth0: transmit timed out
....<6>NETDEV WATCHDOG: eth0: transmit timed out .. timed out!
********************************************************************************/
IP-Config: No network devices available.
NET4: Unix domain sockets 1.0/SMP for Linux NET4.0.
Root-NFS: No NFS server available, giving up.
VFS: Unable to mount root fs via NFS, trying floppy.
request_module[block-major-2]: Root fs not mounted
VFS: Cannot open root device "" or 02:00
Please append a correct "root=" boot option
Kernel panic: VFS: Unable to mount root fs on 02:00



    and I use tcpdump to listen to the eth0, and receive something like that:

          14:34:27.591370 eth0 B 0.0.0.0.bootpc > 255.255.255.255.bootps: xid:0xc6c3f016 secs:88 [|bootp] (DF)
14:34:27.591925 eth0 > 192.168.10.13.bootps > 255.255.255.255.bootpc: xid:0xc6c3f016 secs:88 Y:192.168.10.100 S:192.168.10.13 ether 0:e0:4c:45:56:af [|bootp] (DF)
14:34:27.595609 eth0 > arp who-has 192.168.10.1 tell 192.168.10.13 (0:e0:4c:3b:f6:ca)
14:34:28.591256 eth0 > arp who-has 192.168.10.1 tell 192.168.10.13 (0:e0:4c:3b:f6:ca)
14:34:29.591256 eth0 > arp who-has 192.168.10.1 tell 192.168.10.13 (0:e0:4c:3b:f6:ca)
14:34:30.591402   lo > 192.168.10.13 > 192.168.10.13: icmp: host 192.168.10.1 unreachable [tos 0xc0]
14:34:30.591402   lo < 192.168.10.13 > 192.168.10.13: icmp: host 192.168.10.1 unreachable [tos 0xc0]
14:34:32.601383 eth0 > arp who-has 192.168.10.1 tell 192.168.10.13 (0:e0:4c:3b:f6:ca)
14:34:33.601256 eth0 > arp who-has 192.168.10.1 tell 192.168.10.13 (0:e0:4c:3b:f6:ca)
14:34:34.601256 eth0 > arp who-has 192.168.10.1 tell 192.168.10.13 (0:e0:4c:3b:f6:ca)
14:34:35.601276   lo > 192.168.10.13 > 192.168.10.13: icmp: host 192.168.10.1 unreachable [tos 0xc0]
14:34:35.601276   lo < 192.168.10.13 > 192.168.10.13: icmp: host 192.168.10.1 unreachable [tos 0xc0]
14:34:37.612096 eth0 > arp who-has 192.168.10.1 tell 192.168.10.13 (0:e0:4c:3b:f6:ca)
14:34:38.611257 eth0 > arp who-has 192.168.10.1 tell 192.168.10.13 (0:e0:4c:3b:f6:ca)
14:34:39.611257 eth0 > arp who-has 192.168.10.1 tell 192.168.10.13 (0:e0:4c:3b:f6:ca)
14:34:40.611278   lo > 192.168.10.13 > 192.168.10.13: icmp: host 192.168.10.1 unreachable [tos 0xc0]
14:34:40.611278   lo < 192.168.10.13 > 192.168.10.13: icmp: host 192.168.10.1 unreachable [tos 0xc0]
14:34:42.621330 eth0 > arp who-has 192.168.10.1 tell 192.168.10.13 (0:e0:4c:3b:f6:ca)
14:34:43.621256 eth0 > arp who-has 192.168.10.1 tell 192.168.10.13 (0:e0:4c:3b:f6:ca)
14:34:44.621256 eth0 > arp who-has 192.168.10.1 tell 192.168.10.13 (0:e0:4c:3b:f6:ca)
14:34:45.621277   lo > 192.168.10.13 > 192.168.10.13: icmp: host 192.168.10.1 unreachable [tos 0xc0]
14:34:45.621277   lo < 192.168.10.13 > 192.168.10.13: icmp: host 192.168.10.1 unreachable [tos 0xc0]
14:34:47.633769 eth0 > arp who-has 192.168.10.1 tell 192.168.10.13 (0:e0:4c:3b:f6:ca)
14:34:48.631263 eth0 > arp who-has 192.168.10.1 tell 192.168.10.13 (0:e0:4c:3b:f6:ca)
14:34:49.631256 eth0 > arp who-has 192.168.10.1 tell 192.168.10.13 (0:e0:4c:3b:f6:ca)
14:34:50.631277   lo > 192.168.10.13 > 192.168.10.13: icmp: host 192.168.10.1 unreachable [tos 0xc0]
14:34:50.631277   lo < 192.168.10.13 > 192.168.10.13: icmp: host 192.168.10.1 unreachable [tos 0xc0]
14:34:52.641343 eth0 > arp who-has 192.168.10.1 tell 192.168.10.13 (0:e0:4c:3b:f6:ca)
14:34:53.641271 eth0 > arp who-has 192.168.10.1 tell 192.168.10.13 (0:e0:4c:3b:f6:ca)
14:34:54.641268 eth0 > arp who-has 192.168.10.1 tell 192.168.10.13 (0:e0:4c:3b:f6:ca)
14:34:55.641289   lo > 192.168.10.13 > 192.168.10.13: icmp: host 192.168.10.1 unreachable [tos 0xc0]
14:34:55.641289   lo < 192.168.10.13 > 192.168.10.13: icmp: host 192.168.10.1 unreachable [tos 0xc0]
14:34:55.711924 eth0 B 0.0.0.0.bootpc > 255.255.255.255.bootps: xid:0xc6c3f016 secs:117 [|bootp] (DF)
14:34:55.712391 eth0 > 192.168.10.13.bootps > 255.255.255.255.bootpc: xid:0xc6c3f016 secs:117 Y:192.168.10.100 S:192.168.10.13 ether 0:e0:4c:45:56:af [|bootp] (DF)
14:35:25.712515 eth0 B 0.0.0.0.bootpc > 255.255.255.255.bootps: xid:0xc6c3f016 secs:147 [|bootp] (DF)
14:35:25.713052 eth0 > 192.168.10.13.bootps > 255.255.255.255.bootpc: xid:0xc6c3f016 secs:147 Y:192.168.10.100 S:192.168.10.13 ether 0:e0:4c:45:56:af [|bootp] (DF)



     It seems that the host ack the target's require, but target did't accept . So the target has no right IP address.

     regards.
																			stone




              stone@pocketix.com
                 2002-01-15

** Sent via the linuxppc-embedded mail list. See http://lists.linuxppc.org/

^ permalink raw reply

* Autoconfiguration: Original design scenario
From: Giacomo Catenazzi @ 2002-01-15 10:17 UTC (permalink / raw)
  To: Linux Kernel List, Eric S. Raymond

Hello.

There are a lot of noise about autoconfiguration.
And the scenarios of ESR are not my original scenarios,
for which I worked autoconfigurator for nearly 1.5 years.


A lot of people already compiles the kernel.
(Why? Maybe ESR or other people haw sudied this, but
I don't know the answer)
proof: using the facts:
- there are a lot of kernel.org mirrors.
- posting in the user lists

The people will ocmpile the kernel without the
distribution's configuration, removing not needed
drivers.
(I don't have a proof, but the people that use .config
from distribution, normally use also the updated kernel
source package in the distribution.)

Finding card -> configuration is not easy.
You buy a network card (ethernet), which is the correct
driver? And the usb photo machine? The sound card?
Some info are in configure.help, but you should parse
20/50 entries before maybe to find your card name.


I designed autoconfigure to help these people.
So (at the beggining) a not complete detection,
but used to help the people that ALREADY normally
compile the kernel.


[ In Alan diary, I found that he tried some drivers
before to find the driver for Telsa new tape.
Autoconfigure will help also hackers.
Hmm. Was the card ISA? so forget the above example
]


So do you think autoconfigure can be usefull for people?


After adding a lot of detection and configuration in my
database I found that in a modern machine, autoconfigure
can build a complete and working configuration.

ESR read me autoconfiguration in this late stage, so
he thinks about the 'single button' step for some
aunts, students...

In summary: the autoconfigure is already usefull (IMHO)
for a lot of people.

The other ESR scenarios are 'add-on' without extra working.
They can be usefull, we can make it, but we should see if
distributions/users like the 'one key configuration and
building kernel'. Reading some *-users lists and doing
some support in IRC, I think think people wuould like
to use it.

Anyway these 'add-on' are nearly off-topic to lkml

	giacomo


^ permalink raw reply

* [linux-lvm] xfs quota on lvm
From: Christophe Zwecker @ 2002-01-15 10:13 UTC (permalink / raw)
  To: linux-lvm

Hi,

Ive got alle volumes on linux RH with xfs and all except /  "lvmed".

I got quota enabled in kernel, xfs quota support too. Quota is enabled
at mount. However when I do eduota -u user, I get only to change numbers
on the nonlvm partition.

Is quota nonfunctional on lvm partitions ?

Best regards,

Christophe
-- 
Christophe Zwecker
:Sysctl				
Susannenstr. 26-28		
20357 Hamburg			
phon/fax: +49 40 43099296/7		
mail: czwecker@sysctl.de

^ permalink raw reply

* compile error 2.4.17
From: Silviu Marin-Caea @ 2002-01-15 10:11 UTC (permalink / raw)
  To: linux-kernel

[-- Attachment #1: Type: text/plain, Size: 5574 bytes --]

I'm trying to compile a minimalistic custom kernel for a bootable
diskette.

Environment:

[root@silviu linux]# uname --all; rpm -q glibc gcc
Linux silviu.delrom.ro 2.4.17 #1 Mon Jan 14 21:17:36 EET 2002 i686
unknown glibc-2.2.4-19.3
gcc-2.96-98

Not subscribed to the list, please CC me.  Thanks.

The error:

ld -m elf_i386 -T /usr/src/linux-2.4.17/arch/i386/vmlinux.lds -e stext
arch/i386/kernel/head.o arch/i386/kernel/init_task.o init/main.o
init/version.o \	--start-group \
	arch/i386/kernel/kernel.o arch/i386/mm/mm.o kernel/kernel.o mm/mm.o
fs/fs.o ipc/ipc.o \	 drivers/char/char.o drivers/block/block.o
drivers/misc/misc.o drivers/net/net.o drivers/media/media.o
drivers/ide/idedriver.o drivers/cdrom/driver.o drivers/pci/driver.o
drivers/video/video.o \	net/network.o \
	/usr/src/linux-2.4.17/arch/i386/lib/lib.a
/usr/src/linux-2.4.17/lib/lib.a
/usr/src/linux-2.4.17/arch/i386/lib/lib.a \	--end-group \
	-o vmlinux
fs/fs.o: In function `nfs_xdr_diropargs':
fs/fs.o(.text+0x2f0bb): undefined reference to `xdr_encode_array'
fs/fs.o: In function `nfs_xdr_readres':
fs/fs.o(.text+0x2f3d0): undefined reference to `xdr_zero_iovec'
fs/fs.o: In function `nfs_xdr_createargs':
fs/fs.o(.text+0x2f52c): undefined reference to `xdr_encode_array'
fs/fs.o: In function `nfs_xdr_renameargs':
fs/fs.o(.text+0x2f63b): undefined reference to `xdr_encode_array'
fs/fs.o(.text+0x2f659): undefined reference to `xdr_encode_array'
fs/fs.o: In function `nfs_xdr_linkargs':
fs/fs.o(.text+0x2f6bd): undefined reference to `xdr_encode_array'
fs/fs.o: In function `nfs_xdr_symlinkargs':
fs/fs.o(.text+0x2f70c): undefined reference to `xdr_encode_array'
fs/fs.o(.text+0x2f71a): more undefined references to `xdr_encode_array'
follow fs/fs.o: In function `nfs3_xdr_readdirres':
fs/fs.o(.text+0x36e3e): undefined reference to `xdr_shift_iovec'
fs/fs.o: In function `nfs3_xdr_readlinkres':
fs/fs.o(.text+0x37ec3): undefined reference to `xdr_shift_iovec'
fs/fs.o: In function `nfs3_xdr_readres':
fs/fs.o(.text+0x38102): undefined reference to `xdr_shift_iovec'
fs/fs.o(.text+0x3814f): undefined reference to `xdr_zero_iovec'
fs/fs.o: In function `xdr_encode_mon':
fs/fs.o(.text+0x3db97): undefined reference to `xdr_encode_string'
fs/fs.o(.text+0x3dbab): undefined reference to `xdr_encode_string'
fs/fs.o: In function `nlm_encode_lock':
fs/fs.o(.text+0x3dcaa): undefined reference to `xdr_encode_string'
fs/fs.o(.text+0x3dcd4): undefined reference to `xdr_encode_netobj'
fs/fs.o: In function `nlm_encode_testres':
fs/fs.o(.text+0x3dea7): undefined reference to `xdr_encode_netobj'
fs/fs.o: In function `nlmsvc_decode_testargs':
fs/fs.o(.text+0x3e030): undefined reference to
`xdr_decode_string_inplace' fs/fs.o(.text+0x3e08e): undefined reference
to `xdr_decode_netobj' fs/fs.o: In function `nlmsvc_decode_lockargs':
fs/fs.o(.text+0x3e25d): undefined reference to
`xdr_decode_string_inplace' fs/fs.o(.text+0x3e2be): undefined reference
to `xdr_decode_netobj' fs/fs.o: In function `nlmsvc_decode_cancargs':
fs/fs.o(.text+0x3e47d): undefined reference to
`xdr_decode_string_inplace' fs/fs.o(.text+0x3e4de): undefined reference
to `xdr_decode_netobj' fs/fs.o: In function `nlmsvc_decode_unlockargs':
fs/fs.o(.text+0x3e658): undefined reference to
`xdr_decode_string_inplace' fs/fs.o(.text+0x3e6b3): undefined reference
to `xdr_decode_netobj' fs/fs.o: In function `nlmsvc_decode_shareargs':
fs/fs.o(.text+0x3e85d): undefined reference to
`xdr_decode_string_inplace' fs/fs.o(.text+0x3e8c4): undefined reference
to `xdr_decode_netobj' fs/fs.o: In function `nlmsvc_decode_notify':
fs/fs.o(.text+0x3ea7c): undefined reference to
`xdr_decode_string_inplace' fs/fs.o: In function `nlmsvc_decode_reboot':
fs/fs.o(.text+0x3ead9): undefined reference to
`xdr_decode_string_inplace' fs/fs.o: In function
`nlmclt_decode_testres': fs/fs.o(.text+0x3eddc): undefined reference to
`xdr_decode_netobj' fs/fs.o: In function `nlm4_decode_lock':
fs/fs.o(.text+0x3f47a): undefined reference to
`xdr_decode_string_inplace' fs/fs.o: In function `nlm4_encode_lock':
fs/fs.o(.text+0x3f579): undefined reference to `xdr_encode_string'
fs/fs.o: In function `nlm4_encode_testres':
fs/fs.o(.text+0x3f785): undefined reference to `xdr_encode_netobj'
fs/fs.o: In function `nlm4svc_decode_shareargs':
fs/fs.o(.text+0x3fba0): undefined reference to
`xdr_decode_string_inplace' fs/fs.o: In function
`nlm4svc_decode_notify': fs/fs.o(.text+0x3fccc): undefined reference to
`xdr_decode_string_inplace' fs/fs.o: In function
`nlm4svc_decode_reboot': fs/fs.o(.text+0x3fd19): undefined reference to
`xdr_decode_string_inplace' fs/fs.o: In function `nlm4_decode_oh':
fs/fs.o(.text+0x3f441): undefined reference to `xdr_decode_netobj'
fs/fs.o: In function `nlm4_encode_oh':
fs/fs.o(.text+0x3f451): undefined reference to `xdr_encode_netobj'
net/network.o: In function `xdr_encode_netobj_R29c6f164':
net/network.o(.text+0x427b4): undefined reference to
`_mmx_memcpy_R15670e2d' net/network.o: In function
`xdr_decode_netobj_fixed': net/network.o(.text+0x42816): undefined
reference to `_mmx_memcpy_R15670e2d' net/network.o: In function
`xdr_encode_array_R716530af': net/network.o(.text+0x428ba): undefined
reference to `_mmx_memcpy_R15670e2d' net/network.o: In function
`xdr_shift_iovec_R20fb9f87': net/network.o(.text+0x429dd): undefined
reference to `printk_R1b7d4074' net/network.o(.text+0x42a0f): undefined
reference to `printk_R1b7d4074' net/network.o(.text+0x42a44): undefined
reference to `_mmx_memcpy_R15670e2d' make: *** [vmlinux] Error 1

-- 
Silviu Marin-Caea - Network & Systems Administrator - Delta Romania
Phone +4093-267961

[-- Attachment #2: config --]
[-- Type: application/octet-stream, Size: 15787 bytes --]

#
# Automatically generated by make menuconfig: don't edit
#
CONFIG_X86=y
CONFIG_ISA=y
# CONFIG_SBUS is not set
CONFIG_UID16=y

#
# Code maturity level options
#
CONFIG_EXPERIMENTAL=y

#
# Loadable module support
#
# CONFIG_MODULES is not set

#
# Processor type and features
#
# CONFIG_M386 is not set
# CONFIG_M486 is not set
# CONFIG_M586 is not set
# CONFIG_M586TSC is not set
# CONFIG_M586MMX is not set
# CONFIG_M686 is not set
# CONFIG_MPENTIUMIII is not set
# CONFIG_MPENTIUM4 is not set
# CONFIG_MK6 is not set
CONFIG_MK7=y
# CONFIG_MCRUSOE is not set
# CONFIG_MWINCHIPC6 is not set
# CONFIG_MWINCHIP2 is not set
# CONFIG_MWINCHIP3D is not set
# CONFIG_MCYRIXIII is not set
CONFIG_X86_WP_WORKS_OK=y
CONFIG_X86_INVLPG=y
CONFIG_X86_CMPXCHG=y
CONFIG_X86_XADD=y
CONFIG_X86_BSWAP=y
CONFIG_X86_POPAD_OK=y
# CONFIG_RWSEM_GENERIC_SPINLOCK is not set
CONFIG_RWSEM_XCHGADD_ALGORITHM=y
CONFIG_X86_L1_CACHE_SHIFT=6
CONFIG_X86_TSC=y
CONFIG_X86_GOOD_APIC=y
CONFIG_X86_USE_3DNOW=y
CONFIG_X86_PGE=y
CONFIG_X86_USE_PPRO_CHECKSUM=y
# CONFIG_TOSHIBA is not set
# CONFIG_I8K is not set
# CONFIG_MICROCODE is not set
# CONFIG_X86_MSR is not set
# CONFIG_X86_CPUID is not set
CONFIG_NOHIGHMEM=y
# CONFIG_HIGHMEM4G is not set
# CONFIG_HIGHMEM64G is not set
# CONFIG_MATH_EMULATION is not set
# CONFIG_MTRR is not set
# CONFIG_SMP is not set
# CONFIG_X86_UP_APIC is not set
# CONFIG_X86_UP_IOAPIC is not set

#
# General setup
#
CONFIG_NET=y
CONFIG_PCI=y
# CONFIG_PCI_GOBIOS is not set
# CONFIG_PCI_GODIRECT is not set
CONFIG_PCI_GOANY=y
CONFIG_PCI_BIOS=y
CONFIG_PCI_DIRECT=y
CONFIG_PCI_NAMES=y
# CONFIG_EISA is not set
# CONFIG_MCA is not set
# CONFIG_HOTPLUG is not set
# CONFIG_PCMCIA is not set
# CONFIG_HOTPLUG_PCI is not set
CONFIG_SYSVIPC=y
# CONFIG_BSD_PROCESS_ACCT is not set
CONFIG_SYSCTL=y
CONFIG_KCORE_ELF=y
# CONFIG_KCORE_AOUT is not set
CONFIG_BINFMT_AOUT=y
CONFIG_BINFMT_ELF=y
CONFIG_BINFMT_MISC=y
# CONFIG_PM is not set
# CONFIG_ACPI is not set
# CONFIG_APM is not set

#
# Memory Technology Devices (MTD)
#
# CONFIG_MTD is not set

#
# Parallel port support
#
# CONFIG_PARPORT is not set

#
# Plug and Play configuration
#
CONFIG_PNP=y
# CONFIG_ISAPNP is not set

#
# Block devices
#
CONFIG_BLK_DEV_FD=y
# CONFIG_BLK_DEV_XD is not set
# CONFIG_PARIDE is not set
# CONFIG_BLK_CPQ_DA is not set
# CONFIG_BLK_CPQ_CISS_DA is not set
# CONFIG_BLK_DEV_DAC960 is not set
CONFIG_BLK_DEV_LOOP=y
CONFIG_BLK_DEV_NBD=y
CONFIG_BLK_DEV_RAM=y
CONFIG_BLK_DEV_RAM_SIZE=40960
CONFIG_BLK_DEV_INITRD=y

#
# Multi-device support (RAID and LVM)
#
# CONFIG_MD is not set
# CONFIG_BLK_DEV_MD is not set
# CONFIG_MD_LINEAR is not set
# CONFIG_MD_RAID0 is not set
# CONFIG_MD_RAID1 is not set
# CONFIG_MD_RAID5 is not set
# CONFIG_MD_MULTIPATH is not set
# CONFIG_BLK_DEV_LVM is not set

#
# Networking options
#
CONFIG_PACKET=y
CONFIG_PACKET_MMAP=y
CONFIG_NETLINK_DEV=y
# CONFIG_NETFILTER is not set
# CONFIG_FILTER is not set
CONFIG_UNIX=y
CONFIG_INET=y
CONFIG_IP_MULTICAST=y
# CONFIG_IP_ADVANCED_ROUTER is not set
# CONFIG_IP_PNP is not set
# CONFIG_NET_IPIP is not set
# CONFIG_NET_IPGRE is not set
# CONFIG_IP_MROUTE is not set
# CONFIG_ARPD is not set
# CONFIG_INET_ECN is not set
# CONFIG_SYN_COOKIES is not set
# CONFIG_IPV6 is not set
# CONFIG_KHTTPD is not set
# CONFIG_ATM is not set
# CONFIG_VLAN_8021Q is not set
# CONFIG_IPX is not set
# CONFIG_ATALK is not set
# CONFIG_DECNET is not set
# CONFIG_BRIDGE is not set
# CONFIG_X25 is not set
# CONFIG_LAPB is not set
# CONFIG_LLC is not set
# CONFIG_NET_DIVERT is not set
# CONFIG_ECONET is not set
# CONFIG_WAN_ROUTER is not set
# CONFIG_NET_FASTROUTE is not set
# CONFIG_NET_HW_FLOWCONTROL is not set

#
# QoS and/or fair queueing
#
# CONFIG_NET_SCHED is not set

#
# Telephony Support
#
# CONFIG_PHONE is not set
# CONFIG_PHONE_IXJ is not set
# CONFIG_PHONE_IXJ_PCMCIA is not set

#
# ATA/IDE/MFM/RLL support
#
CONFIG_IDE=y

#
# IDE, ATA and ATAPI Block devices
#
CONFIG_BLK_DEV_IDE=y
# CONFIG_BLK_DEV_HD_IDE is not set
# CONFIG_BLK_DEV_HD is not set
CONFIG_BLK_DEV_IDEDISK=y
CONFIG_IDEDISK_MULTI_MODE=y
# CONFIG_BLK_DEV_IDEDISK_VENDOR is not set
# CONFIG_BLK_DEV_IDEDISK_FUJITSU is not set
# CONFIG_BLK_DEV_IDEDISK_IBM is not set
# CONFIG_BLK_DEV_IDEDISK_MAXTOR is not set
# CONFIG_BLK_DEV_IDEDISK_QUANTUM is not set
# CONFIG_BLK_DEV_IDEDISK_SEAGATE is not set
# CONFIG_BLK_DEV_IDEDISK_WD is not set
# CONFIG_BLK_DEV_COMMERIAL is not set
# CONFIG_BLK_DEV_TIVO is not set
# CONFIG_BLK_DEV_IDECS is not set
CONFIG_BLK_DEV_IDECD=y
# CONFIG_BLK_DEV_IDETAPE is not set
# CONFIG_BLK_DEV_IDEFLOPPY is not set
# CONFIG_BLK_DEV_IDESCSI is not set
CONFIG_BLK_DEV_CMD640=y
# CONFIG_BLK_DEV_CMD640_ENHANCED is not set
# CONFIG_BLK_DEV_ISAPNP is not set
CONFIG_BLK_DEV_RZ1000=y
CONFIG_BLK_DEV_IDEPCI=y
CONFIG_IDEPCI_SHARE_IRQ=y
CONFIG_BLK_DEV_IDEDMA_PCI=y
CONFIG_BLK_DEV_ADMA=y
# CONFIG_BLK_DEV_OFFBOARD is not set
CONFIG_IDEDMA_PCI_AUTO=y
CONFIG_BLK_DEV_IDEDMA=y
# CONFIG_IDEDMA_PCI_WIP is not set
# CONFIG_IDEDMA_NEW_DRIVE_LISTINGS is not set
# CONFIG_BLK_DEV_AEC62XX is not set
# CONFIG_AEC62XX_TUNING is not set
# CONFIG_BLK_DEV_ALI15X3 is not set
# CONFIG_WDC_ALI15X3 is not set
# CONFIG_BLK_DEV_AMD74XX is not set
# CONFIG_AMD74XX_OVERRIDE is not set
# CONFIG_BLK_DEV_CMD64X is not set
# CONFIG_BLK_DEV_CY82C693 is not set
# CONFIG_BLK_DEV_CS5530 is not set
# CONFIG_BLK_DEV_HPT34X is not set
# CONFIG_HPT34X_AUTODMA is not set
# CONFIG_BLK_DEV_HPT366 is not set
# CONFIG_BLK_DEV_PIIX is not set
# CONFIG_PIIX_TUNING is not set
# CONFIG_BLK_DEV_NS87415 is not set
# CONFIG_BLK_DEV_OPTI621 is not set
# CONFIG_BLK_DEV_PDC202XX is not set
# CONFIG_PDC202XX_BURST is not set
# CONFIG_PDC202XX_FORCE is not set
# CONFIG_BLK_DEV_SVWKS is not set
CONFIG_BLK_DEV_SIS5513=y
# CONFIG_BLK_DEV_SLC90E66 is not set
# CONFIG_BLK_DEV_TRM290 is not set
# CONFIG_BLK_DEV_VIA82CXXX is not set
# CONFIG_IDE_CHIPSETS is not set
CONFIG_IDEDMA_AUTO=y
# CONFIG_IDEDMA_IVB is not set
# CONFIG_DMA_NONPCI is not set
CONFIG_BLK_DEV_IDE_MODES=y
# CONFIG_BLK_DEV_ATARAID is not set
# CONFIG_BLK_DEV_ATARAID_PDC is not set
# CONFIG_BLK_DEV_ATARAID_HPT is not set

#
# SCSI support
#
# CONFIG_SCSI is not set

#
# Fusion MPT device support
#
# CONFIG_FUSION is not set
# CONFIG_FUSION_BOOT is not set
# CONFIG_FUSION_ISENSE is not set
# CONFIG_FUSION_CTL is not set
# CONFIG_FUSION_LAN is not set

#
# IEEE 1394 (FireWire) support (EXPERIMENTAL)
#
# CONFIG_IEEE1394 is not set

#
# I2O device support
#
# CONFIG_I2O is not set
# CONFIG_I2O_PCI is not set
# CONFIG_I2O_BLOCK is not set
# CONFIG_I2O_LAN is not set
# CONFIG_I2O_SCSI is not set
# CONFIG_I2O_PROC is not set

#
# Network device support
#
CONFIG_NETDEVICES=y

#
# ARCnet devices
#
# CONFIG_ARCNET is not set
CONFIG_DUMMY=y
# CONFIG_BONDING is not set
# CONFIG_EQUALIZER is not set
# CONFIG_TUN is not set
# CONFIG_ETHERTAP is not set

#
# Ethernet (10 or 100Mbit)
#
CONFIG_NET_ETHERNET=y
# CONFIG_SUNLANCE is not set
# CONFIG_HAPPYMEAL is not set
# CONFIG_SUNBMAC is not set
# CONFIG_SUNQE is not set
# CONFIG_SUNLANCE is not set
# CONFIG_SUNGEM is not set
# CONFIG_NET_VENDOR_3COM is not set
# CONFIG_LANCE is not set
# CONFIG_NET_VENDOR_SMC is not set
# CONFIG_NET_VENDOR_RACAL is not set
# CONFIG_AT1700 is not set
# CONFIG_DEPCA is not set
# CONFIG_HP100 is not set
# CONFIG_NET_ISA is not set
CONFIG_NET_PCI=y
# CONFIG_PCNET32 is not set
# CONFIG_ADAPTEC_STARFIRE is not set
# CONFIG_AC3200 is not set
# CONFIG_APRICOT is not set
# CONFIG_CS89x0 is not set
# CONFIG_TULIP is not set
# CONFIG_DE4X5 is not set
# CONFIG_DGRS is not set
# CONFIG_DM9102 is not set
# CONFIG_EEPRO100 is not set
# CONFIG_LNE390 is not set
# CONFIG_FEALNX is not set
# CONFIG_NATSEMI is not set
# CONFIG_NE2K_PCI is not set
# CONFIG_NE3210 is not set
# CONFIG_ES3210 is not set
# CONFIG_8139CP is not set
# CONFIG_8139TOO is not set
# CONFIG_8139TOO_PIO is not set
# CONFIG_8139TOO_TUNE_TWISTER is not set
# CONFIG_8139TOO_8129 is not set
CONFIG_SIS900=y
# CONFIG_EPIC100 is not set
# CONFIG_SUNDANCE is not set
# CONFIG_TLAN is not set
# CONFIG_VIA_RHINE is not set
# CONFIG_VIA_RHINE_MMIO is not set
# CONFIG_WINBOND_840 is not set
# CONFIG_NET_POCKET is not set

#
# Ethernet (1000 Mbit)
#
# CONFIG_ACENIC is not set
# CONFIG_DL2K is not set
# CONFIG_MYRI_SBUS is not set
# CONFIG_NS83820 is not set
# CONFIG_HAMACHI is not set
# CONFIG_YELLOWFIN is not set
# CONFIG_SK98LIN is not set
# CONFIG_FDDI is not set
# CONFIG_HIPPI is not set
# CONFIG_PLIP is not set
# CONFIG_PPP is not set
# CONFIG_SLIP is not set

#
# Wireless LAN (non-hamradio)
#
# CONFIG_NET_RADIO is not set

#
# Token Ring devices
#
# CONFIG_TR is not set
# CONFIG_NET_FC is not set
# CONFIG_RCPCI is not set
# CONFIG_SHAPER is not set

#
# Wan interfaces
#
# CONFIG_WAN is not set

#
# Amateur Radio support
#
# CONFIG_HAMRADIO is not set

#
# IrDA (infrared) support
#
# CONFIG_IRDA is not set

#
# ISDN subsystem
#
# CONFIG_ISDN is not set

#
# Old CD-ROM drivers (not SCSI, not IDE)
#
# CONFIG_CD_NO_IDESCSI is not set

#
# Input core support
#
# CONFIG_INPUT is not set
# CONFIG_INPUT_KEYBDEV is not set
# CONFIG_INPUT_MOUSEDEV is not set
# CONFIG_INPUT_JOYDEV is not set
# CONFIG_INPUT_EVDEV is not set

#
# Character devices
#
CONFIG_VT=y
CONFIG_VT_CONSOLE=y
CONFIG_SERIAL=y
# CONFIG_SERIAL_CONSOLE is not set
# CONFIG_SERIAL_EXTENDED is not set
# CONFIG_SERIAL_NONSTANDARD is not set
CONFIG_UNIX98_PTYS=y
CONFIG_UNIX98_PTY_COUNT=256

#
# I2C support
#
# CONFIG_I2C is not set

#
# Mice
#
# CONFIG_BUSMOUSE is not set
CONFIG_MOUSE=y
CONFIG_PSMOUSE=y
# CONFIG_82C710_MOUSE is not set
# CONFIG_PC110_PAD is not set

#
# Joysticks
#
# CONFIG_INPUT_GAMEPORT is not set
# CONFIG_QIC02_TAPE is not set

#
# Watchdog Cards
#
# CONFIG_WATCHDOG is not set
# CONFIG_INTEL_RNG is not set
# CONFIG_NVRAM is not set
# CONFIG_RTC is not set
# CONFIG_DTLK is not set
# CONFIG_R3964 is not set
# CONFIG_APPLICOM is not set
# CONFIG_SONYPI is not set

#
# Ftape, the floppy tape device driver
#
# CONFIG_FTAPE is not set
# CONFIG_AGP is not set
# CONFIG_DRM is not set
# CONFIG_MWAVE is not set

#
# Multimedia devices
#
# CONFIG_VIDEO_DEV is not set

#
# File systems
#
# CONFIG_QUOTA is not set
# CONFIG_AUTOFS_FS is not set
# CONFIG_AUTOFS4_FS is not set
# CONFIG_REISERFS_FS is not set
# CONFIG_REISERFS_CHECK is not set
# CONFIG_REISERFS_PROC_INFO is not set
# CONFIG_ADFS_FS is not set
# CONFIG_ADFS_FS_RW is not set
# CONFIG_AFFS_FS is not set
# CONFIG_HFS_FS is not set
# CONFIG_BFS_FS is not set
# CONFIG_EXT3_FS is not set
# CONFIG_JBD is not set
# CONFIG_JBD_DEBUG is not set
CONFIG_FAT_FS=y
CONFIG_MSDOS_FS=y
# CONFIG_UMSDOS_FS is not set
CONFIG_VFAT_FS=y
# CONFIG_EFS_FS is not set
# CONFIG_JFFS_FS is not set
# CONFIG_JFFS2_FS is not set
# CONFIG_CRAMFS is not set
CONFIG_TMPFS=y
# CONFIG_RAMFS is not set
# CONFIG_ISO9660_FS is not set
# CONFIG_JOLIET is not set
# CONFIG_ZISOFS is not set
CONFIG_MINIX_FS=y
# CONFIG_VXFS_FS is not set
CONFIG_NTFS_FS=y
CONFIG_NTFS_RW=y
# CONFIG_HPFS_FS is not set
CONFIG_PROC_FS=y
# CONFIG_DEVFS_FS is not set
# CONFIG_DEVFS_MOUNT is not set
# CONFIG_DEVFS_DEBUG is not set
CONFIG_DEVPTS_FS=y
# CONFIG_QNX4FS_FS is not set
# CONFIG_QNX4FS_RW is not set
# CONFIG_ROMFS_FS is not set
# CONFIG_EXT2_FS is not set
# CONFIG_SYSV_FS is not set
# CONFIG_UDF_FS is not set
# CONFIG_UDF_RW is not set
# CONFIG_UFS_FS is not set
# CONFIG_UFS_FS_WRITE is not set

#
# Network File Systems
#
# CONFIG_CODA_FS is not set
# CONFIG_INTERMEZZO_FS is not set
CONFIG_NFS_FS=y
CONFIG_NFS_V3=y
# CONFIG_ROOT_NFS is not set
# CONFIG_NFSD is not set
# CONFIG_NFSD_V3 is not set
CONFIG_SUNRPC=y
CONFIG_LOCKD=y
CONFIG_LOCKD_V4=y
# CONFIG_SMB_FS is not set
# CONFIG_NCP_FS is not set
# CONFIG_NCPFS_PACKET_SIGNING is not set
# CONFIG_NCPFS_IOCTL_LOCKING is not set
# CONFIG_NCPFS_STRONG is not set
# CONFIG_NCPFS_NFS_NS is not set
# CONFIG_NCPFS_OS2_NS is not set
# CONFIG_NCPFS_SMALLDOS is not set
# CONFIG_NCPFS_NLS is not set
# CONFIG_NCPFS_EXTRAS is not set
# CONFIG_ZISOFS_FS is not set
# CONFIG_ZLIB_FS_INFLATE is not set

#
# Partition Types
#
# CONFIG_PARTITION_ADVANCED is not set
CONFIG_MSDOS_PARTITION=y
# CONFIG_SMB_NLS is not set
CONFIG_NLS=y

#
# Native Language Support
#
CONFIG_NLS_DEFAULT="iso8859-1"
# CONFIG_NLS_CODEPAGE_437 is not set
# CONFIG_NLS_CODEPAGE_737 is not set
# CONFIG_NLS_CODEPAGE_775 is not set
# CONFIG_NLS_CODEPAGE_850 is not set
# CONFIG_NLS_CODEPAGE_852 is not set
# CONFIG_NLS_CODEPAGE_855 is not set
# CONFIG_NLS_CODEPAGE_857 is not set
# CONFIG_NLS_CODEPAGE_860 is not set
# CONFIG_NLS_CODEPAGE_861 is not set
# CONFIG_NLS_CODEPAGE_862 is not set
# CONFIG_NLS_CODEPAGE_863 is not set
# CONFIG_NLS_CODEPAGE_864 is not set
# CONFIG_NLS_CODEPAGE_865 is not set
# CONFIG_NLS_CODEPAGE_866 is not set
# CONFIG_NLS_CODEPAGE_869 is not set
# CONFIG_NLS_CODEPAGE_936 is not set
# CONFIG_NLS_CODEPAGE_950 is not set
# CONFIG_NLS_CODEPAGE_932 is not set
# CONFIG_NLS_CODEPAGE_949 is not set
# CONFIG_NLS_CODEPAGE_874 is not set
# CONFIG_NLS_ISO8859_8 is not set
# CONFIG_NLS_CODEPAGE_1251 is not set
# CONFIG_NLS_ISO8859_1 is not set
# CONFIG_NLS_ISO8859_2 is not set
# CONFIG_NLS_ISO8859_3 is not set
# CONFIG_NLS_ISO8859_4 is not set
# CONFIG_NLS_ISO8859_5 is not set
# CONFIG_NLS_ISO8859_6 is not set
# CONFIG_NLS_ISO8859_7 is not set
# CONFIG_NLS_ISO8859_9 is not set
# CONFIG_NLS_ISO8859_13 is not set
# CONFIG_NLS_ISO8859_14 is not set
# CONFIG_NLS_ISO8859_15 is not set
# CONFIG_NLS_KOI8_R is not set
# CONFIG_NLS_KOI8_U is not set
# CONFIG_NLS_UTF8 is not set

#
# Console drivers
#
CONFIG_VGA_CONSOLE=y
# CONFIG_VIDEO_SELECT is not set
# CONFIG_MDA_CONSOLE is not set

#
# Frame-buffer support
#
# CONFIG_FB is not set

#
# Sound
#
# CONFIG_SOUND is not set

#
# USB support
#
# CONFIG_USB is not set
# CONFIG_USB_UHCI is not set
# CONFIG_USB_UHCI_ALT is not set
# CONFIG_USB_OHCI is not set
# CONFIG_USB_AUDIO is not set
# CONFIG_USB_BLUETOOTH is not set
# CONFIG_USB_STORAGE is not set
# CONFIG_USB_STORAGE_DEBUG is not set
# CONFIG_USB_STORAGE_DATAFAB is not set
# CONFIG_USB_STORAGE_FREECOM is not set
# CONFIG_USB_STORAGE_ISD200 is not set
# CONFIG_USB_STORAGE_DPCM is not set
# CONFIG_USB_STORAGE_HP8200e is not set
# CONFIG_USB_STORAGE_SDDR09 is not set
# CONFIG_USB_STORAGE_JUMPSHOT is not set
# CONFIG_USB_ACM is not set
# CONFIG_USB_PRINTER is not set
# CONFIG_USB_DC2XX is not set
# CONFIG_USB_MDC800 is not set
# CONFIG_USB_SCANNER is not set
# CONFIG_USB_MICROTEK is not set
# CONFIG_USB_HPUSBSCSI is not set
# CONFIG_USB_PEGASUS is not set
# CONFIG_USB_KAWETH is not set
# CONFIG_USB_CATC is not set
# CONFIG_USB_CDCETHER is not set
# CONFIG_USB_USBNET is not set
# CONFIG_USB_USS720 is not set

#
# USB Serial Converter support
#
# CONFIG_USB_SERIAL is not set
# CONFIG_USB_SERIAL_GENERIC is not set
# CONFIG_USB_SERIAL_BELKIN is not set
# CONFIG_USB_SERIAL_WHITEHEAT is not set
# CONFIG_USB_SERIAL_DIGI_ACCELEPORT is not set
# CONFIG_USB_SERIAL_EMPEG is not set
# CONFIG_USB_SERIAL_FTDI_SIO is not set
# CONFIG_USB_SERIAL_VISOR is not set
# CONFIG_USB_SERIAL_IR is not set
# CONFIG_USB_SERIAL_EDGEPORT is not set
# CONFIG_USB_SERIAL_KEYSPAN_PDA is not set
# CONFIG_USB_SERIAL_KEYSPAN is not set
# CONFIG_USB_SERIAL_KEYSPAN_USA28 is not set
# CONFIG_USB_SERIAL_KEYSPAN_USA28X is not set
# CONFIG_USB_SERIAL_KEYSPAN_USA28XA is not set
# CONFIG_USB_SERIAL_KEYSPAN_USA28XB is not set
# CONFIG_USB_SERIAL_KEYSPAN_USA19 is not set
# CONFIG_USB_SERIAL_KEYSPAN_USA18X is not set
# CONFIG_USB_SERIAL_KEYSPAN_USA19W is not set
# CONFIG_USB_SERIAL_KEYSPAN_USA49W is not set
# CONFIG_USB_SERIAL_MCT_U232 is not set
# CONFIG_USB_SERIAL_PL2303 is not set
# CONFIG_USB_SERIAL_CYBERJACK is not set
# CONFIG_USB_SERIAL_XIRCOM is not set
# CONFIG_USB_SERIAL_OMNINET is not set
# CONFIG_USB_RIO500 is not set

#
# Bluetooth support
#
# CONFIG_BLUEZ is not set

#
# Kernel hacking
#
# CONFIG_DEBUG_KERNEL is not set

^ permalink raw reply

* Re: atyfb in 2.5.2
From: Craig Whitmore @ 2002-01-15 10:06 UTC (permalink / raw)
  To: A Guy Called Tyketto; +Cc: linux-kernel
In-Reply-To: <20020115094953.GA24170@wizard.com>

----- Original Message -----
From: "A Guy Called Tyketto" <tyketto@wizard.com>
To: <linux-kernel@vger.kernel.org>
Sent: Tuesday, January 15, 2002 10:49 PM
Subject: atyfb in 2.5.2


>
>         No go for compiling in 2.5.2:
>
> make[2]: Entering directory `/usr/src/linux/drivers/video'
> make -C aty
> make[3]: Entering directory `/usr/src/linux/drivers/video/aty'
> make all_targets
> make[4]: Entering directory `/usr/src/linux/drivers/video/aty'
> gcc -D__KERNEL__ -I/usr/src/linux/include -Wall -Wstrict-prototypes
> -Wno-trigraphs -O2 -fomit-frame-pointer -fno-strict-aliasing -fno-common -
pipe
> -mpreferred-stack-boundary=2 -march=i686 -malign-functions=4
> -DEXPORT_SYMTAB -c atyfb_base.c
> atyfb_base.c: In function `aty_init':
> atyfb_base.c:1989: incompatible types in assignment

I get the same for the rivafb as well (looks like all the fb stuff actually)

   info->node = -1;

commenting out that line made it so it compiled and worked (well looked like
it did when using it , but may not be 100% right )

I dunno if it the right thing to do for the aty FB as well

Can anyone got a proper fix for this?


Thanks
Craig Whitmore
http://www.orcon.net.nz




^ permalink raw reply

* Re: Aunt Tillie builds a kernel (was Re: ISA hardware discovery -- the elegant solution)
From: Horst von Brand @ 2002-01-15 10:05 UTC (permalink / raw)
  To: Eric S. Raymond, Linux Kernel List
In-Reply-To: <20020114125228.B14747@thyrsus.com>

"Eric S. Raymond" <esr@thyrsus.com> said:
> Eli Carter <eli.carter@inet.com>:
> > Could you maybe describe the problem you are trying to solve a bit more
> > clearly than "the hardware-discovery problem for ISA devices"?  If you
> > are trying to discover the ISA devices, but rely upon them having
> > already been discovered, what are you accomplishing?

> Sure.  Let's say Aunt Tillie needs a kernel update.

So Aunt Tillie goes and clicks on "Update distribution", which gets her Red
Hat's up2date or Debian's apt-get or whatever. A reboot later she is happy.

All the nonsense about "faster kernel for K6" and "Nephew Melvin" is just
nonsense. Please do remember the horrors of some of the "latest stable"
kernels, and think thrice before you inflict same on poor Aunt Tillie.

If she wants a kernel for her machine "latest revision", give her a
.configure that builds a fully modular kernel distribution style.

Sure, it would be _way_ cool to have your autodetection stuff. Just:

- ISA is impossible to do right. And on the way out, so irrelevant.
- PCI is rather easy.
- PCMCIA, USB, ... are on the rise. How is your autoconfigurator to detect
  the USB Zip drive Nephew Melvin carries around and uses to backup Aunties
  account from time to time? Or the PCMCIA network card Aunt Tillie is
  keeping in the top drawer for a rainy day? Or the CD burner she plans to
  buy tomorrow?

What would she gain? A smaller kernel (mostly irrelevant, Aunt Tillie sure
hasn't got an 8MB RAM machine), less modules on disk (what, you are
worrying about a few MB on a multi-GB disk?)

As I said before, you are trying to solve a non-problem.

In any case, it's your time. Good luck!
-- 
Horst von Brand			     http://counter.li.org # 22616

^ permalink raw reply

* [OT] NFS locking with NFS-Root
From: Jan-Benedict Glaw @ 2002-01-15  9:05 UTC (permalink / raw)
  To: linux-mips

Hi!

I've got an Indy now, and I want to make it install (with the current
debian dbootstrap) on a NFS root. So I first go to mount the NFS server
to /target and then proceed with the installation. All .deb's get
downloaded, but they cannot be extracted because dpkg can't lock
/var/lib/dpkg/lock .

Dumb question: How do I make file locking (via fcntl(F_SETLK))
functional?

MfG, JBG

-- 
Jan-Benedict Glaw   .   jbglaw@lug-owl.de   .   +49-172-7608481
	 -- New APT-Proxy written in shell script --
	   http://lug-owl.de/~jbglaw/software/ap2/

^ permalink raw reply

* usb.c patch -> successfuly read usb descriptors on some USB device
From: Dmitri Kassatkine @ 2002-01-15  9:59 UTC (permalink / raw)
  To: linux-kernel, Dmitri Kassatkine

Hi,

Sometimes USB subsystem cannot get USB descriptor.

Jan 15 10:44:21 selma kernel: hub.c: USB new device connect on bus1/1, 
assign
ed device number 25
Jan 15 10:44:21 selma kernel: usb.c: couldn't get all of config descriptors
Jan 15 10:44:21 selma kernel: usb.c: unable to get device 25 
configuration (e
rror=-110)


Here is patch how to fix it for 2.4.17. It works for 2.4.16 as well.
 It necassary to read descriptor at once, not first 8 byte first.

It works well now for NSM USB Bluetooth dongle.

br, Dmitri


----------------------------- CUT HERE ---------------------------------------------------------
-- 
 Dmitri Kassatkine
 Nokia Research Center / Helsinki
 Mobile: +358 50 4836365
 E-Mail: dmitri.kassatkine@nokia.com




^ permalink raw reply

* Re: Defining new section for bus driver init
From: Russell King @ 2002-01-15 10:00 UTC (permalink / raw)
  To: Patrick Mochel; +Cc: linux-kernel
In-Reply-To: <Pine.LNX.4.33.0201141746000.827-100000@segfault.osdlab.org>

On Mon, Jan 14, 2002 at 05:47:15PM -0800, Patrick Mochel wrote:
> Attached is a patch that creates a new section for device subsystem init
> calls. With it, the root bus init calls are handled just like init calls
> - the section consists of a table of function pointers.
> device_driver_init() iterates over that table and calls each one.
> (device_driver_init() currently happens just before that pci_init() call
> above).

I've been thinking about this, and would like to suggest something that'd
reduce the code size, but is dependent on the ordering of stuff in
do_basic_setup.  So first some questions.  Currently, we do:

	device_driver_init()
	random bus driver init...
	sock_init()
	start_context_thread()
	do_initcalls()

Is there any ordering dependency between sock_init(), start_context_thread()
and the bus driver init calls?  From a brief look at the code, it would
appear that start_context_thread() is rather safe, but sock_init() is
questionable.  If they are both safe, then we could move these two calls
before, or even just after device_driver_init():

	device_driver_init()
	sock_init()
	start_context_thread()
	random bus driver init...
	do_initcalls()

Now we have the bus driver initialisation and the initcall initialisation
next to each other.  We can then pull this trick with the linker file:

	__initcall_start = .;
	.initcall : {
		*(.devsubsys.init)
		*(.initcall.init)
	}
	__initcall_end = .;

All the magic then happens within do_initcalls() without any extra code
needing to be added.  The really funky thing about this approach is
that you can add other sections to handle network protocol modules
and such like with virtually zero code.

-- 
Russell King (rmk@arm.linux.org.uk)                The developer of ARM Linux
             http://www.arm.linux.org.uk/personal/aboutme.html


^ permalink raw reply

* Re: [linux-lvm] Re: GRUB + LVM + XFS?
From: Adrian Head @ 2002-01-15 10:01 UTC (permalink / raw)
  To: linux-lvm, Patrick Caulfield
In-Reply-To: <20020115153547.GB1022@tykepenguin.com>

On Wed, 16 Jan 2002 01:35, Patrick Caulfield wrote:
> Looking at other threads in this list I think the issues are XFS related. I
> have tried the latest XFS patches from
>
> ftp://oss.sgi.com/projects/xfs/download/patches/2.4.17/
>
> and the snapshots seem OK to me (that's without the VFS lock patch which
> XFS doesn't seem to need anyway).

The original issue was getting ext3, resierfs & XFS coexisting.  I ran tests 
with almost all possible combinations of 2.4.17-xfs & lvm-1.0.1rc4 / 
lvm-1.0.1 CVS.  It would always be that one filesystem was fine but others 
would fail etc...

-- 
Adrian Head

(Public Key available on request.)

^ permalink raw reply

* 2.4.17 instability with i2c ?
From: Shaf Ali @ 2002-01-15  9:59 UTC (permalink / raw)
  To: linux-admin; +Cc: linux-kernel
In-Reply-To: <15425.60130.574569.697952@cerise.nosuchdomain.co.uk>

Hi again,

I am having problems with a machine and cannot pin down why it's abruptly
rebooting...
I can find no messages in any of the logs !

My theories are pointing the blame towards the following configuration :
Redhat 7.2
kernel 2.4.17 patched with i2c-2.6.2.tar.gz.

I am about to attempt building a a fresh kernel... can anyone recommmend a
stable kernel or has anyone experienced problems with 2.4.17 patched with
i2c ?

Many thanks in advance,
Shaf




^ permalink raw reply

* Re: [linux-lvm] Re: GRUB + LVM + XFS?
From: Adrian Head @ 2002-01-15  9:58 UTC (permalink / raw)
  To: linux-lvm, Patrick Caulfield
In-Reply-To: <20020115153547.GB1022@tykepenguin.com>

On Wed, 16 Jan 2002 01:35, Patrick Caulfield wrote:
> Looking at other threads in this list I think the issues are XFS related. I
> have tried the latest XFS patches from
>
> ftp://oss.sgi.com/projects/xfs/download/patches/2.4.17/
>
> and the snapshots seem OK to me (that's without the VFS lock patch which
> XFS doesn't seem to need anyway).
>
> patrick

The actual fix was worked out by Eric of SGI by comparing the Linus tree with 
the LVM code (I hope I have this correct) and it modifies lvm-snap.c - at 
least appears to be an interaction problem.  The weird thing is that this 
fixes the problem if I run my LVM tests by hand - if I use a script it still 
fails.

--- lvm-snap.c	Wed Jan  9 16:10:01 2002
+++ /localhome/eric/lvm-1.0.1-works/lvm-snap.c	Wed Jan  9 16:07:52 2002

http://marc.theaimsgroup.com/?l=linux-xfs&m=101061519711939&w=2

--- usb.c.orig	Wed Nov 21 19:59:11 2001
+++ usb.c	Tue Jan 15 11:38:35 2002
@@ -2041,7 +2041,7 @@
 		return -ENOMEM;
 	}
 
-	buffer = kmalloc(8, GFP_KERNEL);
+	buffer = kmalloc(255, GFP_KERNEL);
 	if (!buffer) {
 		err("unable to allocate memory for configuration descriptors");
 		return -ENOMEM;
@@ -2049,9 +2049,9 @@
 	desc = (struct usb_config_descriptor *)buffer;
 
 	for (cfgno = 0; cfgno < dev->descriptor.bNumConfigurations; cfgno++) {
 		/* We grab the first 8 bytes so we know how long the whole */
 		/*  configuration is */
-		result = usb_get_descriptor(dev, USB_DT_CONFIG, cfgno, buffer, 8);
+		result = usb_get_descriptor(dev, USB_DT_CONFIG, cfgno, buffer, 255);
 		if (result < 8) {
 			if (result < 0)
 				err("unable to get descriptor");
@@ -2072,19 +2072,24 @@
 			goto err;
 		}
 
-		/* Now that we know the length, get the whole thing */
-		result = usb_get_descriptor(dev, USB_DT_CONFIG, cfgno, bigbuffer, length);
-		if (result < 0) {
-			err("couldn't get all of config descriptors");
-			kfree(bigbuffer);
-			goto err;
-		}	
+		if (length > 255) {
+			/* Now that we know the length, get the whole thing */
+			result = usb_get_descriptor(dev, USB_DT_CONFIG, cfgno, bigbuffer, length);
+			if (result < 0) {
+				err("couldn't get all of config descriptors");
+				kfree(bigbuffer);
+				goto err;
+			}	
 	
-		if (result < length) {
-			err("config descriptor too short (expected %i, got %i)", length, result);
-			result = -EINVAL;
-			kfree(bigbuffer);
-			goto err;
+			if (result < length) {
+				err("config descriptor too short (expected %i, got %i)", length, result);
+				result = -EINVAL;
+				kfree(bigbuffer);
+				goto err;
+			}
+		}
+		else {
+			memcpy(bigbuffer, buffer, length);
 		}
 
 		dev->rawdescriptors[cfgno] = bigbuffer;
-------------- CUT HERE ----------------------------------------------------------------------------
@@ -2049,9 +2049,9 @@
 
 	for (cfgno = 0; cfgno < dev->descriptor.bNumConfigurations; cfgno++) {
-		/* We grab the first 8 bytes so we know how long the whole */
+		/* We grab the first 255 bytes so we know how long the whole */
 		/*  configuration is */

-- 
Adrian Head

(Public Key available on request.)

^ permalink raw reply

* [parisc-linux] Solved with kernel 2.4.17-pa11 (was Re: Xfce -3.8.12b error)
From: joel.soete @ 2002-01-15  9:51 UTC (permalink / raw)
  To: joel.soete; +Cc: debian-hppa, debian-x, parisc-linux
In-Reply-To: <1011035188.3c432c3424792@webmail.tiscalinet.be>

Hi all,

Quoting joel.soete@freebel.net:

> Hi all,
> 
> 
> xfwm message (type SessionInit):  X Session Manager not available
> Using builtin session management instead
> 
> aaaa: 1000 1000 1000
> Gdk-ERROR **: BadAccess (attempt to access private resource denied)
>   serial 320 error_code 10 request_code 129 minor_code 3
> Gdk-ERROR **: BadAccess (attempt to access private resource denied)
>   serial 321 error_code 10 request_code 129 minor_code 3
> 
> What ever the kernel I used (2.4.9 or 2.4.17-pa6).

Against all odds, the error is solved with kernel 2.4.17-pa11.

Have nice day too,
       Joel

> 
> I also notice that if I remove .xsession and .xfce then re-run
> xfce_setup, the
> .xsession is not recreated.
> 
> Thanks in advance for help,
>         Joel
> 
> 
> -------------------------------------------------
> This mail sent through Tiscalinet Webmail (http://webmail.tiscali.be)
> 


-------------------------------------------------
This mail sent through Tiscalinet Webmail (http://webmail.tiscali.be)

^ permalink raw reply

* atyfb in 2.5.2
From: A Guy Called Tyketto @ 2002-01-15  9:49 UTC (permalink / raw)
  To: linux-kernel


        No go for compiling in 2.5.2:

make[2]: Entering directory `/usr/src/linux/drivers/video'
make -C aty
make[3]: Entering directory `/usr/src/linux/drivers/video/aty'
make all_targets
make[4]: Entering directory `/usr/src/linux/drivers/video/aty'
gcc -D__KERNEL__ -I/usr/src/linux/include -Wall -Wstrict-prototypes 
-Wno-trigraphs -O2 -fomit-frame-pointer -fno-strict-aliasing -fno-common -pipe 
-mpreferred-stack-boundary=2 -march=i686 -malign-functions=4     
-DEXPORT_SYMTAB -c atyfb_base.c
atyfb_base.c: In function `aty_init':
atyfb_base.c:1989: incompatible types in assignment
make[4]: *** [atyfb_base.o] Error 1
make[4]: Leaving directory `/usr/src/linux/drivers/video/aty'
make[3]: *** [first_rule] Error 2
make[3]: Leaving directory `/usr/src/linux/drivers/video/aty'
make[2]: *** [_subdir_aty] Error 2
make[2]: Leaving directory `/usr/src/linux/drivers/video'
make[1]: *** [_subdir_video] Error 2
make[1]: Leaving directory `/usr/src/linux/drivers'
make: *** [_dir_drivers] Error 2



my config:

#
# Automatically generated make config: don't edit
#
CONFIG_X86=y
CONFIG_ISA=y
# CONFIG_SBUS is not set
CONFIG_UID16=y

#
# Code maturity level options
#
CONFIG_EXPERIMENTAL=y

#
# Loadable module support
#
CONFIG_MODULES=y
CONFIG_MODVERSIONS=y
CONFIG_KMOD=y

#
# Processor type and features
#
# CONFIG_M386 is not set
# CONFIG_M486 is not set
# CONFIG_M586 is not set
# CONFIG_M586TSC is not set
# CONFIG_M586MMX is not set
# CONFIG_M686 is not set
# CONFIG_MPENTIUMIII is not set
# CONFIG_MPENTIUM4 is not set
# CONFIG_MK6 is not set
CONFIG_MK7=y
# CONFIG_MCRUSOE is not set
# CONFIG_MWINCHIPC6 is not set
# CONFIG_MWINCHIP2 is not set
# CONFIG_MWINCHIP3D is not set
# CONFIG_MCYRIXIII is not set
CONFIG_X86_WP_WORKS_OK=y
CONFIG_X86_INVLPG=y
CONFIG_X86_CMPXCHG=y
CONFIG_X86_XADD=y
CONFIG_X86_BSWAP=y
CONFIG_X86_POPAD_OK=y
# CONFIG_RWSEM_GENERIC_SPINLOCK is not set
CONFIG_RWSEM_XCHGADD_ALGORITHM=y
CONFIG_X86_L1_CACHE_SHIFT=6
CONFIG_X86_TSC=y
CONFIG_X86_GOOD_APIC=y
CONFIG_X86_USE_3DNOW=y
CONFIG_X86_PGE=y
CONFIG_X86_USE_PPRO_CHECKSUM=y
# CONFIG_TOSHIBA is not set
# CONFIG_I8K is not set
# CONFIG_MICROCODE is not set
CONFIG_X86_MSR=m
CONFIG_X86_CPUID=m
# CONFIG_NOHIGHMEM is not set
CONFIG_HIGHMEM4G=y
# CONFIG_HIGHMEM64G is not set
CONFIG_HIGHMEM=y
# CONFIG_MATH_EMULATION is not set
CONFIG_MTRR=y
# CONFIG_SMP is not set
CONFIG_X86_UP_APIC=y
CONFIG_X86_UP_IOAPIC=y
CONFIG_X86_LOCAL_APIC=y
CONFIG_X86_IO_APIC=y

#
# General setup
#
CONFIG_NET=y
CONFIG_PCI=y
# CONFIG_PCI_GOBIOS is not set
# CONFIG_PCI_GODIRECT is not set
CONFIG_PCI_GOANY=y
CONFIG_PCI_BIOS=y
CONFIG_PCI_DIRECT=y
CONFIG_PCI_NAMES=y
# CONFIG_EISA is not set
# CONFIG_MCA is not set
# CONFIG_HOTPLUG is not set
# CONFIG_PCMCIA is not set
# CONFIG_HOTPLUG_PCI is not set
CONFIG_SYSVIPC=y
CONFIG_BSD_PROCESS_ACCT=y
CONFIG_SYSCTL=y
CONFIG_KCORE_ELF=y
# CONFIG_KCORE_AOUT is not set
CONFIG_BINFMT_AOUT=m
CONFIG_BINFMT_ELF=y
CONFIG_BINFMT_MISC=m
CONFIG_PM=y
# CONFIG_ACPI is not set
CONFIG_APM=y
# CONFIG_APM_IGNORE_USER_SUSPEND is not set
CONFIG_APM_DO_ENABLE=y
CONFIG_APM_CPU_IDLE=y
CONFIG_APM_DISPLAY_BLANK=y
CONFIG_APM_RTC_IS_GMT=y
# CONFIG_APM_ALLOW_INTS is not set
CONFIG_APM_REAL_MODE_POWER_OFF=y

#
# Memory Technology Devices (MTD)
#
# CONFIG_MTD is not set

#
# Parallel port support
#
CONFIG_PARPORT=m
CONFIG_PARPORT_PC=m
CONFIG_PARPORT_PC_CML1=m
# CONFIG_PARPORT_SERIAL is not set
# CONFIG_PARPORT_PC_FIFO is not set
# CONFIG_PARPORT_PC_SUPERIO is not set
# CONFIG_PARPORT_AMIGA is not set
# CONFIG_PARPORT_MFC3 is not set
# CONFIG_PARPORT_ATARI is not set
# CONFIG_PARPORT_GSC is not set
# CONFIG_PARPORT_SUNBPP is not set
# CONFIG_PARPORT_OTHER is not set
# CONFIG_PARPORT_1284 is not set

#
# Plug and Play configuration
#
CONFIG_PNP=m
CONFIG_ISAPNP=m

#
# Block devices
#
CONFIG_BLK_DEV_FD=m
# CONFIG_BLK_DEV_XD is not set
# CONFIG_PARIDE is not set
# CONFIG_BLK_CPQ_DA is not set
# CONFIG_BLK_CPQ_CISS_DA is not set
# CONFIG_BLK_DEV_DAC960 is not set
CONFIG_BLK_DEV_LOOP=m
# CONFIG_BLK_DEV_NBD is not set
# CONFIG_BLK_DEV_RAM is not set

#
# Multi-device support (RAID and LVM)
#
# CONFIG_MD is not set

#
# Networking options
#
CONFIG_PACKET=m
CONFIG_PACKET_MMAP=y
# CONFIG_NETLINK is not set
CONFIG_NETFILTER=y
CONFIG_NETFILTER_DEBUG=y
# CONFIG_FILTER is not set
CONFIG_UNIX=m
CONFIG_INET=y
# CONFIG_IP_MULTICAST is not set
# CONFIG_IP_ADVANCED_ROUTER is not set
# CONFIG_IP_PNP is not set
# CONFIG_NET_IPIP is not set
# CONFIG_NET_IPGRE is not set
# CONFIG_INET_ECN is not set
CONFIG_SYN_COOKIES=y

#
#   IP: Netfilter Configuration
#
CONFIG_IP_NF_CONNTRACK=m
CONFIG_IP_NF_FTP=m
# CONFIG_IP_NF_IRC is not set
CONFIG_IP_NF_IPTABLES=m
CONFIG_IP_NF_MATCH_LIMIT=m
CONFIG_IP_NF_MATCH_MAC=m
CONFIG_IP_NF_MATCH_MARK=m
CONFIG_IP_NF_MATCH_MULTIPORT=m
CONFIG_IP_NF_MATCH_TOS=m
CONFIG_IP_NF_MATCH_LENGTH=m
CONFIG_IP_NF_MATCH_TTL=m
CONFIG_IP_NF_MATCH_TCPMSS=m
CONFIG_IP_NF_MATCH_STATE=m
# CONFIG_IP_NF_MATCH_UNCLEAN is not set
# CONFIG_IP_NF_MATCH_OWNER is not set
CONFIG_IP_NF_FILTER=m
CONFIG_IP_NF_TARGET_REJECT=m
# CONFIG_IP_NF_TARGET_MIRROR is not set
CONFIG_IP_NF_NAT=m
CONFIG_IP_NF_NAT_NEEDED=y
CONFIG_IP_NF_TARGET_MASQUERADE=m
CONFIG_IP_NF_TARGET_REDIRECT=m
# CONFIG_IP_NF_NAT_SNMP_BASIC is not set
CONFIG_IP_NF_NAT_FTP=m
CONFIG_IP_NF_MANGLE=m
CONFIG_IP_NF_TARGET_TOS=m
CONFIG_IP_NF_TARGET_MARK=m
CONFIG_IP_NF_TARGET_LOG=m
CONFIG_IP_NF_TARGET_TCPMSS=m
CONFIG_IP_NF_COMPAT_IPCHAINS=m
CONFIG_IP_NF_NAT_NEEDED=y
# CONFIG_IP_NF_COMPAT_IPFWADM is not set
# CONFIG_IPV6 is not set
# CONFIG_KHTTPD is not set
# CONFIG_ATM is not set
# CONFIG_VLAN_8021Q is not set

#
#  
#
# CONFIG_IPX is not set
# CONFIG_ATALK is not set
# CONFIG_DECNET is not set
# CONFIG_BRIDGE is not set
# CONFIG_X25 is not set
# CONFIG_LAPB is not set
# CONFIG_LLC is not set
# CONFIG_NET_DIVERT is not set
# CONFIG_ECONET is not set
# CONFIG_WAN_ROUTER is not set
# CONFIG_NET_FASTROUTE is not set
# CONFIG_NET_HW_FLOWCONTROL is not set

#
# QoS and/or fair queueing
#
# CONFIG_NET_SCHED is not set

#
# Telephony Support
#
# CONFIG_PHONE is not set

#
# ATA/IDE/MFM/RLL support
#
CONFIG_IDE=y

#
# IDE, ATA and ATAPI Block devices
#
CONFIG_BLK_DEV_IDE=y

#
# Please see Documentation/ide.txt for help/info on IDE drives
#
# CONFIG_BLK_DEV_HD_IDE is not set
# CONFIG_BLK_DEV_HD is not set
CONFIG_BLK_DEV_IDEDISK=y
# CONFIG_IDEDISK_MULTI_MODE is not set
# CONFIG_BLK_DEV_IDEDISK_VENDOR is not set
# CONFIG_BLK_DEV_COMMERIAL is not set
CONFIG_BLK_DEV_IDECD=m
# CONFIG_BLK_DEV_IDETAPE is not set
# CONFIG_BLK_DEV_IDEFLOPPY is not set
CONFIG_BLK_DEV_IDESCSI=m

#
# IDE chipset support/bugfixes
#
# CONFIG_BLK_DEV_CMD640 is not set
# CONFIG_BLK_DEV_RZ1000 is not set
CONFIG_BLK_DEV_IDEPCI=y
CONFIG_IDEPCI_SHARE_IRQ=y
CONFIG_BLK_DEV_IDEDMA_PCI=y
CONFIG_BLK_DEV_ADMA=y
# CONFIG_BLK_DEV_OFFBOARD is not set
CONFIG_IDEDMA_PCI_AUTO=y
CONFIG_BLK_DEV_IDEDMA=y
# CONFIG_IDEDMA_PCI_WIP is not set
# CONFIG_BLK_DEV_AEC62XX is not set
# CONFIG_BLK_DEV_ALI15X3 is not set
# CONFIG_BLK_DEV_AMD74XX is not set
# CONFIG_BLK_DEV_CMD64X is not set
# CONFIG_BLK_DEV_CY82C693 is not set
# CONFIG_BLK_DEV_CS5530 is not set
# CONFIG_BLK_DEV_HPT34X is not set
# CONFIG_BLK_DEV_HPT366 is not set
# CONFIG_BLK_DEV_PIIX is not set
# CONFIG_BLK_DEV_NS87415 is not set
# CONFIG_BLK_DEV_OPTI621 is not set
# CONFIG_BLK_DEV_PDC202XX is not set
# CONFIG_BLK_DEV_SVWKS is not set
# CONFIG_BLK_DEV_SIS5513 is not set
# CONFIG_BLK_DEV_SLC90E66 is not set
# CONFIG_BLK_DEV_TRM290 is not set
CONFIG_BLK_DEV_VIA82CXXX=y
# CONFIG_IDE_CHIPSETS is not set
CONFIG_IDEDMA_AUTO=y
# CONFIG_IDEDMA_IVB is not set
# CONFIG_DMA_NONPCI is not set
CONFIG_BLK_DEV_IDE_MODES=y
# CONFIG_BLK_DEV_ATARAID is not set

#
# SCSI support
#
CONFIG_SCSI=m

#
# SCSI support type (disk, tape, CD-ROM)
#
CONFIG_BLK_DEV_SD=m
CONFIG_SD_EXTRA_DEVS=40
# CONFIG_CHR_DEV_ST is not set
# CONFIG_CHR_DEV_OSST is not set
CONFIG_BLK_DEV_SR=m
CONFIG_BLK_DEV_SR_VENDOR=y
CONFIG_SR_EXTRA_DEVS=2
CONFIG_CHR_DEV_SG=m

#
# Some SCSI devices (e.g. CD jukebox) support multiple LUNs
#
CONFIG_SCSI_MULTI_LUN=y
CONFIG_SCSI_CONSTANTS=y
# CONFIG_SCSI_LOGGING is not set

#
# SCSI low-level drivers
#
# CONFIG_BLK_DEV_3W_XXXX_RAID is not set
# CONFIG_SCSI_7000FASST is not set
# CONFIG_SCSI_ACARD is not set
# CONFIG_SCSI_AHA152X is not set
# CONFIG_SCSI_AHA1542 is not set
# CONFIG_SCSI_AHA1740 is not set
# CONFIG_SCSI_AIC7XXX is not set
# CONFIG_SCSI_AIC7XXX_OLD is not set
# CONFIG_SCSI_DPT_I2O is not set
# CONFIG_SCSI_ADVANSYS is not set
# CONFIG_SCSI_IN2000 is not set
# CONFIG_SCSI_AM53C974 is not set
# CONFIG_SCSI_MEGARAID is not set
# CONFIG_SCSI_BUSLOGIC is not set
# CONFIG_SCSI_CPQFCTS is not set
# CONFIG_SCSI_DMX3191D is not set
# CONFIG_SCSI_DTC3280 is not set
# CONFIG_SCSI_EATA is not set
# CONFIG_SCSI_EATA_DMA is not set
# CONFIG_SCSI_EATA_PIO is not set
# CONFIG_SCSI_FUTURE_DOMAIN is not set
# CONFIG_SCSI_GDTH is not set
# CONFIG_SCSI_GENERIC_NCR5380 is not set
# CONFIG_SCSI_IPS is not set
# CONFIG_SCSI_INITIO is not set
# CONFIG_SCSI_INIA100 is not set
# CONFIG_SCSI_PPA is not set
# CONFIG_SCSI_IMM is not set
# CONFIG_SCSI_NCR53C406A is not set
# CONFIG_SCSI_NCR53C7xx is not set
# CONFIG_SCSI_SYM53C8XX_2 is not set
# CONFIG_SCSI_NCR53C8XX is not set
# CONFIG_SCSI_SYM53C8XX is not set
# CONFIG_SCSI_PAS16 is not set
# CONFIG_SCSI_PCI2000 is not set
# CONFIG_SCSI_PCI2220I is not set
# CONFIG_SCSI_PSI240I is not set
# CONFIG_SCSI_QLOGIC_FAS is not set
# CONFIG_SCSI_QLOGIC_ISP is not set
# CONFIG_SCSI_QLOGIC_FC is not set
# CONFIG_SCSI_QLOGIC_1280 is not set
# CONFIG_SCSI_SEAGATE is not set
# CONFIG_SCSI_SIM710 is not set
# CONFIG_SCSI_SYM53C416 is not set
# CONFIG_SCSI_DC390T is not set
# CONFIG_SCSI_T128 is not set
# CONFIG_SCSI_U14_34F is not set
# CONFIG_SCSI_ULTRASTOR is not set
# CONFIG_SCSI_DEBUG is not set

#
# Fusion MPT device support
#
# CONFIG_FUSION is not set
# CONFIG_FUSION_BOOT is not set
# CONFIG_FUSION_ISENSE is not set
# CONFIG_FUSION_CTL is not set
# CONFIG_FUSION_LAN is not set

#
# IEEE 1394 (FireWire) support (EXPERIMENTAL)
#
# CONFIG_IEEE1394 is not set

#
# I2O device support
#
# CONFIG_I2O is not set

#
# Network device support
#
CONFIG_NETDEVICES=y

#
# ARCnet devices
#
# CONFIG_ARCNET is not set
CONFIG_DUMMY=m
# CONFIG_BONDING is not set
# CONFIG_EQUALIZER is not set
# CONFIG_TUN is not set
# CONFIG_NET_SB1000 is not set

#
# Ethernet (10 or 100Mbit)
#
CONFIG_NET_ETHERNET=y
# CONFIG_HAPPYMEAL is not set
# CONFIG_SUNGEM is not set
CONFIG_NET_VENDOR_3COM=y
# CONFIG_EL1 is not set
# CONFIG_EL2 is not set
# CONFIG_ELPLUS is not set
# CONFIG_EL16 is not set
# CONFIG_EL3 is not set
# CONFIG_3C515 is not set
# CONFIG_VORTEX is not set
# CONFIG_LANCE is not set
# CONFIG_NET_VENDOR_SMC is not set
# CONFIG_NET_VENDOR_RACAL is not set
# CONFIG_AT1700 is not set
# CONFIG_DEPCA is not set
# CONFIG_HP100 is not set
# CONFIG_NET_ISA is not set
CONFIG_NET_PCI=y
# CONFIG_PCNET32 is not set
# CONFIG_ADAPTEC_STARFIRE is not set
# CONFIG_AC3200 is not set
# CONFIG_APRICOT is not set
# CONFIG_CS89x0 is not set
# CONFIG_DE2104X is not set
CONFIG_TULIP=m
# CONFIG_TULIP_MWI is not set
CONFIG_TULIP_MMIO=y
CONFIG_DE4X5=m
# CONFIG_DGRS is not set
# CONFIG_DM9102 is not set
CONFIG_EEPRO100=m
# CONFIG_FEALNX is not set
# CONFIG_NATSEMI is not set
# CONFIG_NE2K_PCI is not set
# CONFIG_8139CP is not set
# CONFIG_8139TOO is not set
# CONFIG_SIS900 is not set
# CONFIG_EPIC100 is not set
# CONFIG_SUNDANCE is not set
# CONFIG_TLAN is not set
# CONFIG_VIA_RHINE is not set
# CONFIG_WINBOND_840 is not set
# CONFIG_NET_POCKET is not set

#
# Ethernet (1000 Mbit)
#
# CONFIG_ACENIC is not set
# CONFIG_DL2K is not set
# CONFIG_NS83820 is not set
# CONFIG_HAMACHI is not set
# CONFIG_YELLOWFIN is not set
# CONFIG_SK98LIN is not set
# CONFIG_FDDI is not set
# CONFIG_HIPPI is not set
# CONFIG_PLIP is not set
CONFIG_PPP=m
# CONFIG_PPP_MULTILINK is not set
CONFIG_PPP_ASYNC=m
CONFIG_PPP_SYNC_TTY=m
CONFIG_PPP_DEFLATE=m
CONFIG_PPP_BSDCOMP=m
# CONFIG_PPPOE is not set
# CONFIG_SLIP is not set

#
# Wireless LAN (non-hamradio)
#
# CONFIG_NET_RADIO is not set

#
# Token Ring devices
#
# CONFIG_TR is not set
# CONFIG_NET_FC is not set
# CONFIG_RCPCI is not set
# CONFIG_SHAPER is not set

#
# Wan interfaces
#
# CONFIG_WAN is not set

#
# Amateur Radio support
#
# CONFIG_HAMRADIO is not set

#
# IrDA (infrared) support
#
# CONFIG_IRDA is not set

#
# ISDN subsystem
#
# CONFIG_ISDN is not set

#
# Old CD-ROM drivers (not SCSI, not IDE)
#
# CONFIG_CD_NO_IDESCSI is not set

#
# Input core support
#
# CONFIG_INPUT is not set
CONFIG_INPUT_MOUSEDEV_SCREEN_X=1024
CONFIG_INPUT_MOUSEDEV_SCREEN_Y=768

#
# Character devices
#
CONFIG_VT=y
CONFIG_VT_CONSOLE=y
CONFIG_SERIAL=m
# CONFIG_SERIAL_EXTENDED is not set
# CONFIG_SERIAL_NONSTANDARD is not set
CONFIG_UNIX98_PTYS=y
CONFIG_UNIX98_PTY_COUNT=256
CONFIG_PRINTER=m
# CONFIG_LP_CONSOLE is not set
# CONFIG_PPDEV is not set

#
# I2C support
#
# CONFIG_I2C is not set

#
# Mice
#
# CONFIG_BUSMOUSE is not set
CONFIG_MOUSE=m
CONFIG_PSMOUSE=y
# CONFIG_82C710_MOUSE is not set
# CONFIG_PC110_PAD is not set

#
# Joysticks
#
# CONFIG_INPUT_GAMEPORT is not set

#
# Input core support is needed for gameports
#

#
# Input core support is needed for joysticks
#
# CONFIG_QIC02_TAPE is not set

#
# Watchdog Cards
#
CONFIG_WATCHDOG=y
# CONFIG_WATCHDOG_NOWAYOUT is not set
CONFIG_SOFT_WATCHDOG=m
# CONFIG_WDT is not set
# CONFIG_WDTPCI is not set
# CONFIG_PCWATCHDOG is not set
# CONFIG_ACQUIRE_WDT is not set
# CONFIG_ADVANTECH_WDT is not set
# CONFIG_EUROTECH_WDT is not set
# CONFIG_IB700_WDT is not set
# CONFIG_I810_TCO is not set
# CONFIG_MIXCOMWD is not set
# CONFIG_60XX_WDT is not set
# CONFIG_W83877F_WDT is not set
# CONFIG_MACHZ_WDT is not set
# CONFIG_INTEL_RNG is not set
CONFIG_NVRAM=m
CONFIG_RTC=y
# CONFIG_DTLK is not set
# CONFIG_R3964 is not set
# CONFIG_APPLICOM is not set
# CONFIG_SONYPI is not set

#
# Ftape, the floppy tape device driver
#
# CONFIG_FTAPE is not set
CONFIG_AGP=m
# CONFIG_AGP_INTEL is not set
# CONFIG_AGP_I810 is not set
CONFIG_AGP_VIA=y
# CONFIG_AGP_AMD is not set
# CONFIG_AGP_SIS is not set
# CONFIG_AGP_ALI is not set
# CONFIG_AGP_SWORKS is not set
CONFIG_DRM=y
# CONFIG_DRM_TDFX is not set
# CONFIG_DRM_GAMMA is not set
CONFIG_DRM_R128=m
CONFIG_DRM_RADEON=m
# CONFIG_DRM_I810 is not set
# CONFIG_DRM_MGA is not set
# CONFIG_MWAVE is not set

#
# Multimedia devices
#
# CONFIG_VIDEO_DEV is not set

#
# File systems
#
# CONFIG_QUOTA is not set
# CONFIG_AUTOFS_FS is not set
# CONFIG_AUTOFS4_FS is not set
CONFIG_REISERFS_FS=m
# CONFIG_REISERFS_CHECK is not set
# CONFIG_REISERFS_PROC_INFO is not set
# CONFIG_ADFS_FS is not set
# CONFIG_AFFS_FS is not set
# CONFIG_HFS_FS is not set
# CONFIG_BFS_FS is not set
CONFIG_EXT3_FS=y
CONFIG_JBD=y
CONFIG_JBD_DEBUG=y
CONFIG_FAT_FS=m
CONFIG_MSDOS_FS=m
# CONFIG_UMSDOS_FS is not set
CONFIG_VFAT_FS=m
# CONFIG_EFS_FS is not set
# CONFIG_CRAMFS is not set
CONFIG_TMPFS=y
CONFIG_RAMFS=y
CONFIG_ISO9660_FS=m
CONFIG_JOLIET=y
CONFIG_ZISOFS=y
CONFIG_MINIX_FS=m
# CONFIG_VXFS_FS is not set
# CONFIG_NTFS_FS is not set
# CONFIG_HPFS_FS is not set
CONFIG_PROC_FS=y
CONFIG_DEVFS_FS=y
CONFIG_DEVFS_MOUNT=y
CONFIG_DEVFS_DEBUG=y
CONFIG_DEVPTS_FS=y
# CONFIG_QNX4FS_FS is not set
# CONFIG_ROMFS_FS is not set
CONFIG_EXT2_FS=y
# CONFIG_SYSV_FS is not set
# CONFIG_UDF_FS is not set
# CONFIG_UFS_FS is not set

#
# Network File Systems
#
# CONFIG_CODA_FS is not set
# CONFIG_INTERMEZZO_FS is not set
CONFIG_NFS_FS=m
CONFIG_NFS_V3=y
CONFIG_NFSD=m
CONFIG_NFSD_V3=y
CONFIG_SUNRPC=m
CONFIG_LOCKD=m
CONFIG_LOCKD_V4=y
# CONFIG_SMB_FS is not set
# CONFIG_NCP_FS is not set
CONFIG_ZISOFS_FS=m
CONFIG_ZLIB_FS_INFLATE=m

#
# Partition Types
#
# CONFIG_PARTITION_ADVANCED is not set
CONFIG_MSDOS_PARTITION=y
# CONFIG_SMB_NLS is not set
CONFIG_NLS=y

#
# Native Language Support
#
CONFIG_NLS_DEFAULT="cp437"
CONFIG_NLS_CODEPAGE_437=m
# CONFIG_NLS_CODEPAGE_737 is not set
# CONFIG_NLS_CODEPAGE_775 is not set
CONFIG_NLS_CODEPAGE_850=m
CONFIG_NLS_CODEPAGE_852=m
# CONFIG_NLS_CODEPAGE_855 is not set
# CONFIG_NLS_CODEPAGE_857 is not set
# CONFIG_NLS_CODEPAGE_860 is not set
# CONFIG_NLS_CODEPAGE_861 is not set
# CONFIG_NLS_CODEPAGE_862 is not set
CONFIG_NLS_CODEPAGE_863=m
# CONFIG_NLS_CODEPAGE_864 is not set
# CONFIG_NLS_CODEPAGE_865 is not set
# CONFIG_NLS_CODEPAGE_866 is not set
# CONFIG_NLS_CODEPAGE_869 is not set
# CONFIG_NLS_CODEPAGE_936 is not set
# CONFIG_NLS_CODEPAGE_950 is not set
# CONFIG_NLS_CODEPAGE_932 is not set
# CONFIG_NLS_CODEPAGE_949 is not set
# CONFIG_NLS_CODEPAGE_874 is not set
# CONFIG_NLS_ISO8859_8 is not set
# CONFIG_NLS_CODEPAGE_1251 is not set
CONFIG_NLS_ISO8859_1=m
# CONFIG_NLS_ISO8859_2 is not set
# CONFIG_NLS_ISO8859_3 is not set
# CONFIG_NLS_ISO8859_4 is not set
# CONFIG_NLS_ISO8859_5 is not set
# CONFIG_NLS_ISO8859_6 is not set
# CONFIG_NLS_ISO8859_7 is not set
# CONFIG_NLS_ISO8859_9 is not set
# CONFIG_NLS_ISO8859_13 is not set
# CONFIG_NLS_ISO8859_14 is not set
CONFIG_NLS_ISO8859_15=m
# CONFIG_NLS_KOI8_R is not set
# CONFIG_NLS_KOI8_U is not set
# CONFIG_NLS_UTF8 is not set

#
# Console drivers
#
CONFIG_VGA_CONSOLE=y
CONFIG_VIDEO_SELECT=y
# CONFIG_MDA_CONSOLE is not set

#
# Frame-buffer support
#
CONFIG_FB=y
CONFIG_DUMMY_CONSOLE=y
# CONFIG_FB_RIVA is not set
# CONFIG_FB_CLGEN is not set
# CONFIG_FB_PM2 is not set
# CONFIG_FB_CYBER2000 is not set
# CONFIG_FB_VESA is not set
# CONFIG_FB_VGA16 is not set
# CONFIG_FB_HGA is not set
CONFIG_VIDEO_SELECT=y
# CONFIG_FB_MATROX is not set
CONFIG_FB_ATY=y
# CONFIG_FB_ATY_GX is not set
CONFIG_FB_ATY_CT=y
# CONFIG_FB_RADEON is not set
# CONFIG_FB_ATY128 is not set
# CONFIG_FB_SIS is not set
# CONFIG_FB_3DFX is not set
# CONFIG_FB_VOODOO1 is not set
# CONFIG_FB_VIRTUAL is not set
CONFIG_FBCON_ADVANCED=y
# CONFIG_FBCON_MFB is not set
# CONFIG_FBCON_CFB2 is not set
# CONFIG_FBCON_CFB4 is not set
CONFIG_FBCON_CFB8=y
CONFIG_FBCON_CFB16=y
CONFIG_FBCON_CFB24=y
CONFIG_FBCON_CFB32=y
# CONFIG_FBCON_AFB is not set
# CONFIG_FBCON_ILBM is not set
# CONFIG_FBCON_IPLAN2P2 is not set
# CONFIG_FBCON_IPLAN2P4 is not set
# CONFIG_FBCON_IPLAN2P8 is not set
# CONFIG_FBCON_MAC is not set
# CONFIG_FBCON_VGA_PLANES is not set
# CONFIG_FBCON_VGA is not set
# CONFIG_FBCON_HGA is not set
# CONFIG_FBCON_FONTWIDTH8_ONLY is not set
# CONFIG_FBCON_FONTS is not set
CONFIG_FONT_8x8=y
CONFIG_FONT_8x16=y

#
# Sound
#
CONFIG_SOUND=m
# CONFIG_SOUND_BT878 is not set
# CONFIG_SOUND_CMPCI is not set
# CONFIG_SOUND_EMU10K1 is not set
# CONFIG_SOUND_FUSION is not set
# CONFIG_SOUND_CS4281 is not set
# CONFIG_SOUND_ES1370 is not set
# CONFIG_SOUND_ES1371 is not set
# CONFIG_SOUND_ESSSOLO1 is not set
# CONFIG_SOUND_MAESTRO is not set
# CONFIG_SOUND_MAESTRO3 is not set
# CONFIG_SOUND_ICH is not set
# CONFIG_SOUND_RME96XX is not set
# CONFIG_SOUND_SONICVIBES is not set
# CONFIG_SOUND_TRIDENT is not set
# CONFIG_SOUND_MSNDCLAS is not set
# CONFIG_SOUND_MSNDPIN is not set
# CONFIG_SOUND_VIA82CXXX is not set
CONFIG_SOUND_OSS=m
# CONFIG_SOUND_TRACEINIT is not set
# CONFIG_SOUND_DMAP is not set
# CONFIG_SOUND_AD1816 is not set
# CONFIG_SOUND_SGALAXY is not set
# CONFIG_SOUND_ADLIB is not set
# CONFIG_SOUND_ACI_MIXER is not set
# CONFIG_SOUND_CS4232 is not set
# CONFIG_SOUND_SSCAPE is not set
# CONFIG_SOUND_GUS is not set
CONFIG_SOUND_VMIDI=m
# CONFIG_SOUND_TRIX is not set
# CONFIG_SOUND_MSS is not set
# CONFIG_SOUND_MPU401 is not set
# CONFIG_SOUND_NM256 is not set
# CONFIG_SOUND_MAD16 is not set
# CONFIG_SOUND_PAS is not set
# CONFIG_SOUND_PSS is not set
CONFIG_SOUND_SB=m
# CONFIG_SOUND_AWE32_SYNTH is not set
# CONFIG_SOUND_WAVEFRONT is not set
# CONFIG_SOUND_MAUI is not set
CONFIG_SOUND_YM3812=m
# CONFIG_SOUND_OPL3SA1 is not set
# CONFIG_SOUND_OPL3SA2 is not set
# CONFIG_SOUND_YMFPCI is not set
# CONFIG_SOUND_UART6850 is not set
# CONFIG_SOUND_AEDSP16 is not set

#
# USB support
#
# CONFIG_USB is not set

#
# USB Host Controller Drivers
#

#
# USB Device Class drivers
#

#
# USB Human Interface Devices (HID)
#

#
#   Input core support is needed for USB HID
#

#
# USB Imaging devices
#

#
# USB Multimedia devices
#

#
#   Video4Linux support is needed for USB Multimedia device support
#

#
# USB Network adaptors
#

#
# USB port drivers
#

#
# USB Serial Converter support
#

#
# USB Miscellaneous drivers
#

#
# Bluetooth support
#
# CONFIG_BLUEZ is not set

#
# Kernel hacking
#
CONFIG_DEBUG_KERNEL=y
# CONFIG_DEBUG_HIGHMEM is not set
CONFIG_DEBUG_SLAB=y
CONFIG_DEBUG_IOVIRT=y
CONFIG_MAGIC_SYSRQ=y
CONFIG_DEBUG_SPINLOCK=y
CONFIG_DEBUG_BUGVERBOSE=y

#
# Library routines
#
# CONFIG_CRC32 is not set
-- 
Brad Littlejohn                         | Email:        tyketto@wizard.com
Unix Systems Administrator,             |           tyketto@ozemail.com.au
Web + NewsMaster, BOFH.. Smeghead! :)   |   http://www.wizard.com/~tyketto
  PGP: 1024D/E319F0BF 6980 AAD6 7329 E9E6 D569  F620 C819 199A E319 F0BF


^ permalink raw reply

* usb.c patch -> successfuly read usb descriptors on some USB device
From: Dmitri Kassatkine @ 2002-01-15  9:47 UTC (permalink / raw)
  To: linux-kernel; +Cc: Kassatkine Dmitri (NRC/Helsinki)

[-- Attachment #1: Type: text/plain, Size: 641 bytes --]

Hi,

Sometimes USB subsystem cannot get USB descriptor.

Jan 15 10:44:21 selma kernel: hub.c: USB new device connect on bus1/1, 
assign
ed device number 25
Jan 15 10:44:21 selma kernel: usb.c: couldn't get all of config descriptors
Jan 15 10:44:21 selma kernel: usb.c: unable to get device 25 
configuration (e
rror=-110)


Here is patch how to fix it for 2.4.17. It works for 2.4.16 as well.
 It necassary to read descriptor at once, not first 8 byte first.

It works well now for NSM USB Bluetooth dongle.

br, DMitri

-- 
 Dmitri Kassatkine
 Nokia Research Center / Helsinki
 Mobile: +358 50 4836365
 E-Mail: dmitri.kassatkine@nokia.com


[-- Attachment #2: usb.c.patch-2.4.17 --]
[-- Type: text/plain, Size: 1840 bytes --]

--- usb.c.orig	Wed Nov 21 19:59:11 2001
+++ usb.c	Tue Jan 15 11:38:35 2002
@@ -2041,7 +2041,7 @@
 		return -ENOMEM;
 	}
 
-	buffer = kmalloc(8, GFP_KERNEL);
+	buffer = kmalloc(255, GFP_KERNEL);
 	if (!buffer) {
 		err("unable to allocate memory for configuration descriptors");
 		return -ENOMEM;
@@ -2049,9 +2049,9 @@
 	desc = (struct usb_config_descriptor *)buffer;
 
 	for (cfgno = 0; cfgno < dev->descriptor.bNumConfigurations; cfgno++) {
 		/* We grab the first 8 bytes so we know how long the whole */
 		/*  configuration is */
-		result = usb_get_descriptor(dev, USB_DT_CONFIG, cfgno, buffer, 8);
+		result = usb_get_descriptor(dev, USB_DT_CONFIG, cfgno, buffer, 255);
 		if (result < 8) {
 			if (result < 0)
 				err("unable to get descriptor");
@@ -2072,19 +2072,24 @@
 			goto err;
 		}
 
-		/* Now that we know the length, get the whole thing */
-		result = usb_get_descriptor(dev, USB_DT_CONFIG, cfgno, bigbuffer, length);
-		if (result < 0) {
-			err("couldn't get all of config descriptors");
-			kfree(bigbuffer);
-			goto err;
-		}	
+		if (length > 255) {
+			/* Now that we know the length, get the whole thing */
+			result = usb_get_descriptor(dev, USB_DT_CONFIG, cfgno, bigbuffer, length);
+			if (result < 0) {
+				err("couldn't get all of config descriptors");
+				kfree(bigbuffer);
+				goto err;
+			}	
 	
-		if (result < length) {
-			err("config descriptor too short (expected %i, got %i)", length, result);
-			result = -EINVAL;
-			kfree(bigbuffer);
-			goto err;
+			if (result < length) {
+				err("config descriptor too short (expected %i, got %i)", length, result);
+				result = -EINVAL;
+				kfree(bigbuffer);
+				goto err;
+			}
+		}
+		else {
+			memcpy(bigbuffer, buffer, length);
 		}
 
 		dev->rawdescriptors[cfgno] = bigbuffer;

^ permalink raw reply

* [linux-lvm] problem with mounting xfs LVs under 2.4.17-ia64
From: Walter de Jong @ 2002-01-15  9:42 UTC (permalink / raw)
  To: linux-lvm

Hi,

We're running debian (woody dist) on an IA64.
The kernel is 2.4.17 with 2 patches applied:
- linux-2.4.17-ia64-011226.diff
- linux-2.4.17-xfs-2002-01-06.cvs-patch
@@ -2049,9 +2049,9 @@
 
 	for (cfgno = 0; cfgno < dev->descriptor.bNumConfigurations; cfgno++) {
-		/* We grab the first 8 bytes so we know how long the whole */
+		/* We grab the first 255 bytes so we know how long the whole */
 		/*  configuration is */

We use lvm utils 1.0.1-rc4

When trying to mount the filesystem, we get:

ns5# mount -t xfs /dev/sara_vg/home /mnt
Segmentation fault

Jan 15 16:01:14 ns5 kernel: lvm -- lvm_blk_ioctl: unknown command 0x40081271
Jan 15 16:02:54 ns5 kernel: I/O error in filesystem ("lvm(58,0)") meta-data dev 0x0 block 0x0
Jan 15 16:02:54 ns5 kernel:        ("xfs_read_buf") error 2099955072 buf count 0
Jan 15 16:02:54 ns5 kernel:
Jan 15 16:02:54 ns5 kernel: Pid: 2810, comm:                mount
Jan 15 16:02:54 ns5 kernel: psr : 0000101008022018 ifs : 8000000000000004 ip  : [pagebuf_delwri_dequ
eue+144/320]    Not tainted
Jan 15 16:02:54 ns5 kernel: unat: 0000000000000000 pfs : 000000000000040c rsc : 0000000000000003
Jan 15 16:02:54 ns5 kernel: rnat: 3736353433323130 bsps: e00000025ca77870 pr  : 000000000002091b
Jan 15 16:02:54 ns5 kernel: ldrs: 0000000000000000 ccv : 0000000000000000 fpsr: 0009804c8a70033f
Jan 15 16:02:54 ns5 kernel: b0  : e0000000046db0c0 b6  : e00000000483dda0 b7  : e000000004491730
Jan 15 16:02:54 ns5 kernel: f6  : 1003e00000000000000a0 f7  : 1003e00000000000000a0
Jan 15 16:02:54 ns5 kernel: f8  : 100008000000000000000 f9  : 10002a000000000000000
Jan 15 16:02:54 ns5 kernel: r1  : e000000004b713d0 r2  : 0000000000000000 r3  : e000000004a0c490
Jan 15 16:02:54 ns5 kernel: r8  : 0000000000000077 r9  : 0000000000000894 r10 : 0000000000000000
Jan 15 16:02:54 ns5 kernel: r11 : 0000000000020a5b r12 : e00000025ca77990 r13 : e00000025ca70000
Jan 15 16:02:54 ns5 kernel: r14 : 0000000000000008 r15 : 00000000007cfff0 r16 : 0000000000000000
Jan 15 16:02:54 ns5 kernel: r17 : e000000278dbc848 r18 : e000000004b806d0 r19 : 0000001008026018
Jan 15 16:02:54 ns5 kernel: r20 : e000000264f48060 r21 : 000000000000ff00 r22 : 0000000000000fff
Jan 15 16:02:54 ns5 kernel: r23 : e000000004b81588 r24 : 0000001008026018 r25 : 0000000000000000
Jan 15 16:02:54 ns5 kernel: r26 : 0000000000000000 r27 : e00000025ca71588 r28 : 000000000002099b
Jan 15 16:02:54 ns5 kernel: r29 : 0000000000000001 r30 : 0000000000000000 r31 : 0000000000000000
Jan 15 16:02:54 ns5 kernel: r32 : 0000000000000000 r33 : 0000000000000000 r34 : 0000000000000000
Jan 15 16:02:54 ns5 kernel: r35 : 0000000000000000
Jan 15 16:02:54 ns5 kernel:
Jan 15 16:02:54 ns5 kernel: Call Trace: [show_stack+80/192] sp=0xe00000025ca77580 bsp=0xe00000025ca7
1538
Jan 15 16:02:54 ns5 kernel: [show_regs+1936/1984] sp=0xe00000025ca77740 bsp=0xe00000025ca714e0
Jan 15 16:02:54 ns5 kernel: [die+400/544] sp=0xe00000025ca77760 bsp=0xe00000025ca714b8
Jan 15 16:02:54 ns5 kernel: [ia64_do_page_fault+2112/2400] sp=0xe00000025ca77760 bsp=0xe00000025ca71
460
Jan 15 16:02:54 ns5 kernel: [ia64_leave_kernel+0/656] sp=0xe00000025ca777f0 bsp=0xe00000025ca71460
Jan 15 16:02:54 ns5 kernel: [pagebuf_delwri_dequeue+144/320] sp=0xe00000025ca77990 bsp=0xe00000025ca
71440
Jan 15 16:02:54 ns5 kernel: [<e000000278dbc870>] sp=0xe00000025ca77990 bsp=0xe00000025ca71440
Jan 15 16:02:54 ns5 kernel: [xfs_read_buf+480/672] sp=0xe00000025ca77990 bsp=0xe00000025ca71440
Jan 15 16:02:54 ns5 kernel: [<e00000025ca77800>] sp=0xe00000025ca77990 bsp=0xe00000025ca710b8

xfs on a regular disk partition does work, so I think it's caused by:
"lvm_blk_ioctl: unknown command 0x40081271"

Please help anyone?

-- 
                  *** If you build it, they will come ***

Walter de Jong
walter@sara.nl        http://www.sara.nl/
HPC Systems Programmer at SARA Computing and Network Services

People should be able to e-mail me, spambots should not.

^ permalink raw reply

* Re: [linux-lvm] LVM patches on LKML - are they needed?
From: Heinz J . Mauelshagen @ 2002-01-15  9:42 UTC (permalink / raw)
  To: linux-lvm
In-Reply-To: <E16QVUz-0004HP-00@hermes.sistina.com>

On Wed, Jan 16, 2002 at 01:27:29AM +1000, Adrian Head wrote:
> Recently - there was a tread on the LKML 
> "[lvm-devel] [PATCH][2.5.2-pre11] lvm critical fixes | where is the lvm 
> maintainer?"
> http://marc.theaimsgroup.com/?l=linux-kernel&m=101080017328995&w=2
> 
> Does anyone know whether the patches in this thread apply to the 2.4.x branch 
> or the 2.5.x branch? LVM1 or LVM2?

It is Linux 1.5.x and LVM1

> 
> If they are needed for the 2.4.x branch - will they be in CVS soon?

We don't have the capacity to emphasize on LVM1 in 2.5 right now because
we support LVM1 in 2.4 and will release LVM2 including a new driver probably
this week and would like people embracing that new enhanced architecture which
will support the given on disk metadata.

There was third party help to upgrade the LVM1 driver to work in 2.5
and we really would appreciate more in that area.

> 
> -- 
> Adrian Head
> 
> (Public Key available on request.)
> 
> _______________________________________________
> linux-lvm mailing list
> linux-lvm@sistina.com
> http://lists.sistina.com/mailman/listinfo/linux-lvm
> read the LVM HOW-TO at http://www.sistina.com/lvm/Pages/howto.html

-- 

Regards,
Heinz    -- The LVM Guy --

*** Software bugs are stupid.
    Nevertheless it needs not so stupid people to solve them ***

=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-

Heinz Mauelshagen                                 Sistina Software Inc.
Senior Consultant/Developer                       Am Sonnenhang 11
                                                  56242 Marienrachdorf
                                                  Germany
Mauelshagen@Sistina.com                           +49 2626 141200
                                                       FAX 924446
=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-

^ permalink raw reply

* Re: [linux-lvm] Re: GRUB + LVM + XFS?
From: Patrick Caulfield @ 2002-01-15  9:36 UTC (permalink / raw)
  To: linux-lvm
In-Reply-To: <E16QVJv-0003Zk-00@hermes.sistina.com>

On Wed, Jan 16, 2002 at 01:16:15AM +1000, Adrian Head wrote:
> The issue was that when I tried to create an XFS snapshot it would Oops and 
> the snapshot creation would not have been completed.  The /dev/vg/lv entries 
> would not be there; however, vgdisplay would show the snapshot as being in 
> use but I could not remove the incomplete snapshot.
> 
> When I would reboot using a lvm-1.0.1 kernel (2.4.17-xfs+lvm1.0.1) - the 
> machine would hang during startup; however, if I used a lvm-1.0.1rc4(ish) 
> kernel (2.4.16-xfs+lvm1.0.1rc4) it would fix the problem on the fly during 
> bootup and the snapshot would be put in full operation without problems.  
> This was the only way I found to get the machine up & running again.
> 
> I don't have any info on which lines of code might have been the cause.  I'm 
> still learning how to dig in and dbug.  ;-)

Looking at other threads in this list I think the issues are XFS related. I have
tried the latest XFS patches from

ftp://oss.sgi.com/projects/xfs/download/patches/2.4.17/

and the snapshots seem OK to me (that's without the VFS lock patch which XFS
doesn't seem to need anyway).

patrick

^ permalink raw reply

* Re: [PATCH] need_resched abstraction
From: Jeff Garzik @ 2002-01-15  9:29 UTC (permalink / raw)
  To: David Howells; +Cc: torvalds, linux-kernel
In-Reply-To: <23480.1011085988@warthog.cambridge.redhat.com>

Call me picky but I like the name cond_resched()   ;-)
-- 
Jeff Garzik      | Alternate titles for LOTR:
Building 1024    | Fast Times at Uruk-Hai
MandrakeSoft     | The Took, the Elf, His Daughter and Her Lover
                 | Samwise Gamgee: International Hobbit of Mystery

^ permalink raw reply

* Re: [Linux-ia64] Help with Ingo scheduler on IA64
From: Erich Focht @ 2002-01-15  9:28 UTC (permalink / raw)
  To: linux-ia64
In-Reply-To: <marc-linux-ia64-105590698805816@msgid-missing>

[-- Attachment #1: Type: TEXT/PLAIN, Size: 1110 bytes --]

Hi Nick,

maybe the defconfig-bigsur-mp is a bit old, I could not find any
definition of CONFIG_IA64_GRANULE_64MB or CONFIG_IA64_GRANULE_16MB which
actually would mean that IA64_GRANULE_SIZE could be wrong. I attached a
gzipped diff of the two configs, I had only minor changes to the
default arch/ia64/defconfig. ACPI is definitely configured in.

On Mon, 14 Jan 2002, Nick Pollitt wrote:

> What .config are you using?  I grabbed the defconfig-bigsur-mp
> and compiled with your patch (had to disable DEVFS_DEBUG).  The
> kernel doesn't get very far into the boot, less than a second,
> and it fails.  Of course you said it would.  But I couldn't get
> any useful info from the console so I ran the kernel in medusa.

I don't have medusa and that's not free, I suppose...

> In case you try this, it executes to about 15301000.  Then it
> fails in acpi_hw_low_level_read.  I also tried with the kernel
> patch I sent out Friday, which dies much sooner than this.  But
> it's definitely not getting into schedule in my machine.
> 
> Did you config off other stuff (all the ACPI)? 
> 
> Nick

Regards,

Erich


[-- Attachment #2: Type: APPLICATION/x-gunzip, Size: 2569 bytes --]

^ permalink raw reply

* [linux-lvm] LVM patches on LKML - are they needed?
From: Adrian Head @ 2002-01-15  9:28 UTC (permalink / raw)
  To: linux-lvm

Recently - there was a tread on the LKML 
"[lvm-devel] [PATCH][2.5.2-pre11] lvm critical fixes | where is the lvm 
maintainer?"
http://marc.theaimsgroup.com/?l=linux-kernel&m=101080017328995&w=2

Does anyone know whether the patches in this thread apply to the 2.4.x branch 
or the 2.5.x branch? LVM1 or LVM2?

If they are needed for the 2.4.x branch - will they be in CVS soon?

-- 
Adrian Head

(Public Key available on request.)

^ permalink raw reply


This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
all data and code used by this external index.